function [resampled_data, resampled_time, New_N] = block_resample(time,data,input_sample_rate,output_sample_rate);
%   [resampled_data, resampled_time, New_N] = block_resample(time,data,input_sample_rate,output_sample_rate);
%
%   This routine resamples the data with tim gaps
%
%   Inputs:
%       time = time file (with possible gaps)
%       data = the data matrix (with possible gaps)
%       input_sample_rate = the input sample rate
%       output_sample_rate = the output sample rate
%
%   Outputs:
%       resampled_data = resampled data matrix
%       resampled_time = resampled time
%       New_N = new # of data points
%

%
%   First determine the dimensions of the input data
%
dimensions_in = max(size(size(data)));
pre_size = size(data);
[big_dimension_in, index] = max(pre_size);
if index ~= dimensions_in
    'Last dimension not largest'
    return;
end
%
%   Set output data sizes
%
big_dimension_out = ceil(big_dimension_in*output_sample_rate/input_sample_rate);
resampled_data = zeros([pre_size(1:dimensions_in-1),big_dimension_out]);
resampled_time(big_dimension_out) = 0;
New_N = big_dimension_out;
%
%   Find gaps
%
delta_value(big_dimension_in-1) = 0;
for i=1:big_dimension_in-1
    delta_value(i) = round((time(i+1)-time(i))*input_sample_rate*86400);
end
%
%   A gap is only a gap if it would be at both the input and output sample rates
%
gap_count = 0;
'Finding gaps'
for i=1:big_dimension_in-1
    if delta_value(i) ~= 1
        out_delta = floor(delta_value(i)*input_sample_rate/output_sample_rate);
        if out_delta > 10
            gap_count = gap_count+1;
            gap_location(gap_count) = i;
        end
%        delta_value(i),i
    end
end
gap_count;
gap_location;
start_index = 1;
end_index = big_dimension_in;
output_start_index = 1;
output_end_index = 1;
'Doing gaps'
for i=1:gap_count
   end_index = gap_location(i);
   delta_index = ceil((1+end_index-start_index)*output_sample_rate/input_sample_rate);
   output_end_index = output_start_index + delta_index - 1;
   %
   %   Add buffer points to start and end
   %
   clear the_time filt_time
   for j=1:100
       the_time(j) = time(start_index) - 1.157407407407407e-005*((101 - j)/input_sample_rate);
   end
   the_time(101:(101+end_index-start_index)) = time(start_index:end_index);
   for j=1:100
       the_time(101+end_index-start_index+j) = time(end_index) + 1.157407407407407e-005*(j/input_sample_rate);
   end
   %
   %   Now filter
   %
   filt_time = resample(the_time,output_sample_rate,input_sample_rate,0);
%   size(filt_time)
%   size(the_time)
   %
   %   Now remove the buffer data
   %
   buffer_count = 1 + round((length(filt_time) - delta_index)*0.5);
   resampled_time(output_start_index:output_end_index) = filt_time(buffer_count:delta_index+buffer_count-1);
   output_start_index = output_end_index+1;
   start_index = end_index+1;
end
%
%   Now do the last segment (or if there were no segments, the whole dataset)
%
clear the_time filt_time
end_index = big_dimension_in;
delta_index = ceil((1+end_index-start_index)*output_sample_rate/input_sample_rate);
output_end_index = output_start_index + delta_index-1;
%
%   Add buffer points to start and end
%
for j=1:100
    the_time(j) = time(start_index) - 1.157407407407407e-005*((101 - j)/input_sample_rate);
end
the_time(101:(101+end_index-start_index)) = time(start_index:end_index);
for j=1:100
    the_time(101+end_index-start_index+j) = time(end_index) + 1.157407407407407e-005*(j/input_sample_rate);
end
test_var = the_time;
%
%   Now filter
%
filt_time = resample(the_time,output_sample_rate,input_sample_rate,0);
%
%   Now remove the buffer data
%
buffer_count = 1 + round((length(filt_time) - delta_index)*0.5);
resampled_time(output_start_index:output_end_index) = filt_time(buffer_count:delta_index+buffer_count-1);
%
%   do all of multi-dimensional data as one block
%
start_index = 1;
'Doing data file'
switch dimensions_in
case 1
    the_data = data;
    %
    %   Now filter
    %
    resampled_data = resample(the_data,output_sample_rate,input_sample_rate);
case 2
    for j=1:pre_size(1)
        the_data = data(j,:);
        %
        %   Now filter, then remove buffer
        %
        filt_data = resample(the_data,output_sample_rate,input_sample_rate);
        resampled_data(j,:) = filt_data;
    end
case 3
    for j=1:pre_size(1)
        for k=1:pre_size(2)
            the_data = data(j,k,:);
            %
            %   Now filter, then remove buffer
            %
            filt_data = resample(the_data,output_sample_rate,input_sample_rate);
            resampled_data(j,k,:) = filt_data;
        end
    end
case 4
    for j=1:pre_size(1)
        for k=1:pre_size(2)
            for l=1:pre_size(3)
                the_data = data(j,k,l,:);
                %
                %   Now filter, then remove buffer
                %
                filt_data = resample(the_data,output_sample_rate,input_sample_rate);
                resampled_data(j,k,l,:) = filt_data;
            end
        end
    end
end
%
%   The end
%
return;
