% 
% File:   clusterim.m
% Date:   17-Oct-97 
% Author: I. Chuang <ike@isl.stanford.edu>
% 
% MATLAB5 script: read in an image with white dots and find where they
% are located, quantitatively.

function [x,y] = clusterim3(fname)

[im,cmap] = tiffread([fname '.tif']);	% read in image

if(~isgray(im))				% make sure it's grayscale
  disp('oops, image not grayscale!');
end

% bw1 = im2bw(im,0.5);		% threshold to get peaks
% bw1 = im2bw(im,0.4);		% threshold to get peaks
bw1 = im2bw(im,0.35);		% threshold to get peaks
bw2 = bwmorph(bw1,'close');	% do boundary closure
bw3 = bwmorph(bw2,'fill');	% fill isolated empty pixels
bw4 = bwmorph(bw3,'thicken',5);	% thicken patch regions w/o connecting
[cim,num] = bwlabel(bw4);	% label each connected region

% at this point, cim is a matrix which contains the integer n at each
% point inside the nth connected region.  a connected region is a connected
% blob of points.

% make a grid of point locations...so im(i,j) is located at gx(i,j),gy(i,j)
% this makes it easy to calculate location of the blobs
[gx,gy] = meshgrid(1:size(im,2),1:size(im,1));
npix = prod(size(im));		% number of pixels in the image
ysize = size(im,1);

for k = 1:max(max(cim))		% loop over each connected region found
  c = (cim==k) .* im;		% extract the kth connected region
  wt = npix/sum(sum(c));	% find <x>,<y> by taking a weighted mean
  x(k) = mean2(gx.*c)*wt;
  y(k) = ysize - mean2(gy.*c)*wt;
end

return
