function [mill_E_matrix] = convert_V_2_E(efm_data_matrix,V_2_E_matrix,mill_list);
%	function [mill_E_matrix] = convert_V_2_E(efm_data_matrix, V_2_E_matrix, mill_list)
%
%	This routine determines the E electric field at each mill (and both gains) from the mill 
%		voltage values
%
%	Inputs:
%		efm_data_matrix = the (A,B,N) matrix of mill voltage values (A gains, B mills, N values)
%		V_2_E_matrix = the (G*2+1,X) matrix of V to E values for the G gains at each of X mills
%        
%     mill_list = the list of mills in each of the B locations (so that we can use the correct
%        calibration curve)
%
%	Outputs:
%		mill_E_matrix = the (A,B,N) matrix of the electric fields at each mill (and all gains)
%

%
%  Make the output the same size as the input
%
how_big = size(efm_data_matrix);
gains = how_big(1)
mills = how_big(2)
points = how_big(3)
totals = size(V_2_E_matrix);
available_mills = totals(2);
mill_E_matrix(gains, mills, points) = 0;
'Pre-Sized'
%
%   Now determine which mill is in whic location
%
for mill_location=1:mills
    %
    %   We assume the mill ID's are in the list, if not use the last one
    %
    mill_ID = mill_list(mill_location);
    for cal_index=1:available_mills
       if mill_ID == V_2_E_matrix(1,cal_index)
          break;
       end
    end
    slot = cal_index;
    for gain_index=1:gains
       gain = V_2_E_matrix(gain_index*2 + 1,slot);
       offset = V_2_E_matrix(gain_index*2,slot);
       mill_E_matrix(gain_index,mill_location,:) = efm_data_matrix(gain_index,mill_location,:)*gain + offset;
    end
 end
 
