function [En,Ew,Eu] = convert_a_2_fe_E_man(Ex, Ey, Ez, roll, pitch);
%	[En, Ew, Eu] = convert_a_2_fe_E_man(Ex, Ey, Ez, roll, pitch)
%
%	This routine determines the flat earth frame (En (nose), Ew (wing), and Eu (up)) electric fields from the aircraft (X, Y, Z)
%		frame data.  Note that a positive roll and pitch angle is CCW.  The 
%		transformations are in the following order:
%
%			Ee = R*P*Ea
%
%		If this is the wrong order or orientation, the output will be wrong.
%
%	Inputs:
%		Ex, Ey, Ez = the (N) matrix of aircraft E data (Ex, Ey, Ez)
%		roll, pitch = the (N) matrix of aircraft orientation (roll, pitch)
%			(note that the orientation matrix needs to be resampled to the aircraft data rate)
%
%	Outputs:
%		En, Ew, Eu = the (N) matrix of the earth oriented (En (nose), Ew (wing), Eu (up)) electric fields
%

%
%	Size the data
%
Ntot = length(Ex);
En(Ntot) = 0;
Ew(Ntot) = 0;
Eu(Ntot) = 0;
one(Ntot) = 1;
zero(Ntot) = 0;
for i=1:Ntot
   one(i) = 1;
   zero(i) = 0;
end
Roll(3,3,Ntot) = 0;
Pitch(3,3,Ntot) = 0;
%
%	Constant
%
deg_2_rad = pi/180.0;
%
%	Do data
%
roll_sin = sin(roll*deg_2_rad);
roll_cos = cos(roll*deg_2_rad);
Roll(1,1,:) = one;
Roll(2,2,:) = roll_cos;
Roll(3,3,:) = roll_cos;
Roll(1,2,:) = zero;
Roll(1,3,:) = zero;
Roll(2,1,:) = zero;
Roll(3,1,:) = zero;
Roll(2,3,:) = -roll_sin;
Roll(3,2,:) = roll_sin;
%Roll = [one zero zero; zero roll_cos -roll_sin; zero roll_sin roll_cos];
pitch_sin = sin(pitch*deg_2_rad);
pitch_cos = cos(pitch*deg_2_rad);
Pitch(1,1,:) = pitch_cos;
Pitch(1,2,:) = zero;
Pitch(1,3,:) = -pitch_sin;
Pitch(2,1,:) = zero;
Pitch(2,2,:) = one;
Pitch(2,3,:) = zero;
Pitch(3,1,:) = pitch_sin;
Pitch(3,2,:) = zero;
Pitch(3,3,:) = pitch_cos;
aircraft = [Ex; Ey; Ez];
size(Roll)
size(Pitch)
size(aircraft)
Roll(:,:,1)
Pitch(:,:,1)
%
%	Now do matrix math
%
for i=1:Ntot
   Eflat = Roll(:,:,i)*Pitch(:,:,i)*aircraft(:,i);
   En(i) = Eflat(1);
   Ew(i) = Eflat(2);
   Eu(i) = Eflat(3);
end
