function [mill_E_matrix] = convert_dc8V_2_E(efm_data_matrix,V_2_E_matrix,mill_list);
%	function [mill_E_matrix] = convert_dc8V_2_E(efm_data_matrix, V_2_E_matrix, mill_list);
%
%	This routine determines the E electric field at each mill (and both gains) from the mill 
%		voltage values
%
%	Inputs:
%		efm_data_matrix = the (4,6,N) matrix of mill voltage values
%		V_2_E_matrix = the (8,6) matrix of V to E values for the two gains at each of 8 mills
%           we assume the mills are S# 21-28 
%       mill_list = the list of mills in each of the 6 locations (so that we can use the correct
%           calibration curve) (NOT USED FOR NOW)
%
%	Outputs:
%		mill_E_matrix = the (2,6,N) matrix of the electric fields at each mill (and both gains)
%

%
%	First, build the best set of mill data
%	(use sensitive gain unless near saturation)
%
how_big = length(efm_data_matrix);
mill_E_matrix(4,6,how_big) = 0;
'Pre-Sized'
%
%   Now determine which mill is in whic location
%
calibration_matrix(6,4) = 0;
offset_matrix(6,4) = 0;
for mill_location=1:6
    %
    %   We assume we are using mills with S# from 1-8
    %
    slot = mill_list(mill_location);
    start_index = 1;
    while V_2_E_matrix(start_index,1) ~= slot
       start_index = start_index + 1;
    end
    %
    % Found set of values
    %
    while V_2_E_matrix(start_index,1) == slot
       gain = 5 - V_2_E_matrix(start_index,2);
       calibration_matrix(mill_location,gain) = V_2_E_matrix(start_index,3);
       offset_matrix(mill_location,gain) = V_2_E_matrix(start_index,4);
       start_index = start_index + 1;
       if start_index == 29
          break;
       end
    end
end
calibration_matrix
offset_matrix
for mill_index=1:6
   for gain_index=1:4
      mill_E_matrix(gain_index,mill_index,:) = (efm_data_matrix(gain_index,mill_index,:)-offset_matrix(mill_index,gain_index))/calibration_matrix(mill_index,gain_index);
   end
end
