function [mill_E_matrix,aircraft_E_matrix] = convert_earth_2_mill_E(earth_data_matrix,E_2_mill_conversion_matrix, orientation_matrix);
%	[mill_E_matrix, aircraft_E_matrix] = convert_earth_2_mill_E(earth_data_matrix, E_2_mill_conversion_matrix, orientation_matrix)
%
%	This routine determines what the mills "should" be seeing based on the current E_2_mill_oconversion_matrix
%
%	Inputs:
%			earth_E_matrix = the (6,N) matrix of the earth oriented (En, Ew, Eu, Q, Emag, Qfactor) electric fields
%			E_2_mill_conversion_matrix = the 6x4 matrix to convert the external E to the mill outputs
%				(inverse of the convert_mill_2_aircraft_E conversion_matrix)
%			orientation_matrix = the (3,N) matrix of aircraft orientation
%
%	Outputs:
%		mill_E_matrix = the (2,6,N) matrix of mill electric field values
%			note that the sensitive and insensitive gains will be the same (format kept the same
%			for ease of plotting)
%		aircraft_E_matrix = the (6,N) matrix of the aircraft oriented (Ex, Ey, Ez, Q, Emag, Qfactor) electric fields
%

%
%	Size the data
%
Ntot = length(earth_data_matrix);
mill_E_matrix(2,6,Ntot) = 0;
M_data(6,Ntot) = 0;
aircraft_E_matrix(6,Ntot) = 0;
%
%	Constant
%
deg_2_rad = pi/180.0;
%
%	Do loop
%
for data_index=1:Ntot
   roll_sin = sin(-orientation_matrix(1,data_index)*deg_2_rad);
   roll_cos = cos(-orientation_matrix(1,data_index)*deg_2_rad);
   Roll = [1 0 0 0 0 0; 0 roll_cos -roll_sin 0 0 0; 0 roll_sin roll_cos 0 0 0; 0 0 0 1 0 0; 0 0 0 0 1 0; 0 0 0 0 0 1];
   pitch_sin = sin(-orientation_matrix(2,data_index)*deg_2_rad);
   pitch_cos = cos(-orientation_matrix(2,data_index)*deg_2_rad);
   Pitch = [pitch_cos 0 -pitch_sin 0 0 0; 0 1 0 0 0 0; pitch_sin 0 pitch_cos 0 0 0; 0 0 0 1 0 0; 0 0 0 0 1 0; 0 0 0 0 0 1];
   heading_sin = sin(-orientation_matrix(3,data_index)*deg_2_rad);
   heading_cos = cos(-orientation_matrix(3,data_index)*deg_2_rad);
   Heading = [heading_cos heading_sin 0 0 0 0; -heading_sin heading_cos 0 0 0 0; 0 0 1 0 0 0; 0 0 0 1 0 0; 0 0 0 0 1 0; 0 0 0 0 0 1];
   %
   %	Now do matrix math
   %
%   aircraft_E_matrix(:,data_index) = Heading*Pitch*Roll*earth_data_matrix(:,data_index);
   aircraft_E_matrix(:,data_index) = Pitch*Roll*earth_data_matrix(:,data_index);
end
%
%	Do conversion
%
E_data(1:4,:) = aircraft_E_matrix(1:4,:);
M_data = E_2_mill_conversion_matrix*E_data;
%
%	Now fill out format
%
mill_E_matrix(1,:,:) = M_data;
mill_E_matrix(2,:,:) = M_data;
