function [earth_E_matrix,aircraft_E_matrix,gain_matrix,no_cal_mill_E_matrix,best_mill] = convert_mill_2_earth_E(time,efm_data_matrix,conversion_matrix,orientation_matrix);
%	function [earth_E_matrix, aircraft_E_matrix, gain_matrix, no_cal_mill_E_matrix, best_mill_matrix] = 
%     convert_mill_2_earth_E(time, mill_E_matrix,conversion_matrix,orientation_matrix)
%
%	This routine determines the earth frame (North, West,Up) electric fields from the mill (PD, PU, ...)
%		data.  It uses the convert_mill_2_aircraft_E and convert_aircraft_2_earth_E routines.
%
%	Inputs:
%       time = the N array of datenum time values
%		mill_E_matrix = the (2,6,N) matrix of mill electric field values
%		conversion_matrix = the (4,6) matrix to convert a mill set of E to an aircraft set of E
%		orientation_matrix = the (3,N) matrix of aircraft orientation (roll, pitch, heading)
%			(note that the orientation matrix needs to be resampled to the aircraft data rate)
%
%	Output:
%		earth_E_matrix = the (6,N) matrix of the earth oriented (En, Ew, Eu, Q, Emag, Qfactor) electric fields
%		aircraft_E_matrix = the (6,N) matrix of the aircraft oriented (Ex, Ey, Ez, Q, Emag, Qfactor) electric fields
%		gain_matrix = the (6,N) matrix of gains used in the calculations (1=sensitive, 2=insensitive)
%       no_cal_mill_E_matrix = the mill_E_matrix (2,6,N) without the calibration pulses
%       best_mill_matrix = the mill_E_matrix with only one gain (6,N) the one use to determine the E
%

%
%  Fix the calibration pulses, if possible
%
[no_cal_mill_E_matrix] = remove_calibration_pulse(efm_data_matrix,time);
%
%	Call the first routine
%
[aircraft_E_matrix, best_mill, gain_matrix] = convert_mill_2_aircraft_E(no_cal_mill_E_matrix,conversion_matrix);
%
%	Now call the second
%
earth_E_matrix = convert_aircraft_2_earth_E(aircraft_E_matrix,orientation_matrix);
