function mill = sget_mill_data(fid)
%
%    This function reads (and decodes) the mill data.
%

%
%  M.G. Bateman, USRA, 17 Aug 1998
%  mod by Mach, 4/21/03
%

global CurrentFile;
global MillCnt;
global Mill;
global MillIdx;
global MillSpeed;
global MillSpeedIdx;
global MillSN;
global plot_insens;
global FF;

plot_insens = 0;

%
%   The mills have a FSV of +/- 2.5 volts.  That corresponds to +/- 8.333 kV/m.
%   So the scaling factor for 16-bit A/D is (16.666/65536) = 2.543 x 10^-4.
%   Or +/- 150 kV/m on the insensitive channel.

% conv_ins = (300/65536);
% conv     = (16.666/65536);
%
%  ... it ain't necessarily so...
%

%
% Voltage levels:  5 Volts / 65536

%
%  Also: divide by form factor.
%

conv_ins = (5/65536);
conv     = (5/65536);

MillSN = [];

for i = 1:MillCnt
   buf = fread(fid,10);  % read the channel header
   
   if(buf(1) ~= 'D')
      disp(sprintf('MILL DATA HDR: Sync problem!? in file %s', CurrentFile))
   end

   % version = buf(2);
   size = 256*buf(4) + buf(3);

   if size == 214
      millhdr = fread(fid, 12);
      id = fix(millhdr(3) / 8);
      MillSN = [ MillSN id ];
      sens = fread(fid, 50, 'short');
      insens = fread(fid, 50, 'short');
      CRC = fread(fid, 1, 'short');

      speed = rem(millhdr(8), 64);     % lower 6 bits of the 8th byte

      if plot_insens == 1
         Mill(i,MillIdx:MillIdx+49) = (conv_ins/FF(i))*insens';
      else
         Mill(i,MillIdx:MillIdx+49) = (conv/FF(i))*sens';
      end

      MillSpeed(i,MillSpeedIdx) = speed;
      
   elseif size > 0   %  skip over short packets
      buf = fread(fid, size);
      MillSN = [ MillSN 0 ];
   else
      MillSN = [ MillSN 0 ];
   end
end

MillIdx = MillIdx + 50;
MillSpeedIdx = MillSpeedIdx + 1;


