function [E_gof, rms] = goodness_of_Efit(ideal_E, E_est, emphasis);
% function [E_gof, rms] = goodness_of_Efit(ideal_E, E_est);
%
% This routine creates two sets of "goodness of fit", one for E components and one for
%  overall E field
%
% Inputs:
%  ideal_E = the "ideal" fields given the roll/pitch data
%  est_E = the estimated E based on the current C/M matrix
%
% Output:
%  E_gof = the vector goodness of fit for the E data
%  rms = the sum of squares of the goodness of fit
%
%  Note: I do not really care if the Eq matches, so the rms value
%  will NOT contain any emphasis on the Eq
%
   
%
%  Calculate differences between the true mill outputs and the one based on the "fields"
%
E_gof = E_est - ideal_E;
%
%  Do RMS "error"
%  (take out Eq)
%
Ef_gof = E_gof(1:3,:);
the_square = rot90(Ef_gof.*Ef_gof);
%the_square(:,1) = the_square(:,1).*emphasis;
sum_square = sum(the_square);
sum_sqrt = sqrt(sum_square);
rms = sum_sqrt(1)*sum_sqrt(2)*sum_sqrt(3);


