function [mill_gof, rms] = goodness_of_fit(best_mill, cm, ic);
% function [mill_gof, rms] = goodness_of_fit(best_mill, cm, ic);
%
% This routine creates two sets of "goodness of fit", one for mill output and one
%  overall mill fit
%
%
% Inputs:
%  best_mill = the fields at the mills used to create the field_data_matrix
%  cm = calibration matrix
%  ic = inverse calibration matrix
%
% Output:
%  mill_gof = the goodness of fit for mill data
%  rms = the sum of squares of the goodness of fit
%
   
%
%  First get the field components
%
E = cm*best_mill;
%
%  Now calculate the "mill outputs" based on the E estimate
%
m_est = ic*E;
%
%  Calculate differences between the true mill outputs and the one based on the "fields"
%
mill_gof = m_est - best_mill;
%
%  Do RMS "error"
%
the_square = rot90(mill_gof.*mill_gof);
sum_square = sum(the_square);
sum_sqrt = sqrt(sum_square);
rms = sum_sqrt(1) + sum_sqrt(2) + sum_sqrt(3) + sum_sqrt(4) + sum_sqrt(5) + sum_sqrt(6);


