function [POS_block] = init_pos_block(size, type);
%        [ POS_block ] = init_pos_block(size, type);
%
%	Inits one POS block from the file fid and
%	writes it to the structure POS_block.
%
%	POS structure:
%		lat = latitude of aircraft
%		long = longitude of aircraft
%		speed = speed of aircraft in m/s (ground speed or airspeed?)
%		track = ground heading of aircraft
%		roll = roll angle of aircraft
%		pitch = pitch of aircraft
%		head = heading of aircraft (magnetic or true?)
%		alt = altitude of aircraft (meters)
%		dX = X acceleration (m/s**2)
%		dY = Y acceleration (m/s**2)
%		dZ = Z acceleration (m/s**2)
%		valid = POS time of validity (?)
%		GPS = POS GPS time
%		ice = ice detector LWC (gm/m**3)
%		LWC = FSSP LWC (gm/m**3)
%		two_d = 2D concentrations (p/liter)
%
%	type = anything if large struct wanted (leave out if want small struct)
%

%
%	Init the data
%
POS_block(size).lat = 0;
POS_block(size).long = 0;
POS_block(size).speed = 0;
POS_block(size).track = 0;
POS_block(size).roll = 0;
POS_block(size).pitch = 0;
POS_block(size).head = 0;
POS_block(size).alt = 0;
if ~exist('type')
   POS_block(size).dX = 0;
	POS_block(size).dY = 0;
	POS_block(size).dZ = 0;
	POS_block(size).valid = 0;
	POS_block(size).GPS = 0;
	POS_block(size).ice = 0;
	POS_block(size).LWC = 0;
   POS_block(size).two_d = 0;
end
%
%	That is all!
%
