function [aircraft_E_matrix,best_mill,gain] = konvert_mill_2_aircraft_E(efm_data_matrix,k_matrix,l_matrix);
%	function [aircraft_K_matrix, best_mill, gain] = konvert_mill_2_aircraft_E(mill_E_matrix, k_matrix, l_matrix)
%
%	This routine determines the aircraft frame electric fields from the mill electric fields
%
%	Inputs:
%		mill_E_matrix = the (2,6,N) matrix of mill electric field values
%		k_matrix = the (4,4) matrix to convert a mill set of E to an aircraft set of E (plus slack term)
%     l_matrix = the (4,6) matrix of mill values to use in the k matrix
%
%	Outputs:
%		aircraft_E_matrix = the (6,N) matrix of the aircraft oriented electric fields
%			Ex, Ey, Ez, Eq, Emag, Slackfactor (subjective quality of the vector E data based on K matrix theory). 
%           Note that for the k-matrix version, the Eq is not produced
%           and will be set to NaN for plotting purposes
%       best_mill = (6,N) matrix of the mll values used in the aircraft E electric field calculations
%		gain = the (6,N) matrix of gains used in the calculations (1=sensitive, 2=insensitive)
%

%
%	First, build the best set of mill data
%	(use sensitive gain unless near saturation)
%
up_factor = 0.95;
down_factor = 0.25;
low_gain_max_E = 60000;
E_limit = low_gain_max_E*up_factor;
E_minit = low_gain_max_E*down_factor;
how_big = length(efm_data_matrix);
best_mill(6,how_big) = 0;
gain(6,how_big) = 0;
last_gain(1:6) = 1;
best_mill = squeeze(efm_data_matrix(1,:,:));
for value_index=1:how_big
   for mill_index=1:6
      if last_gain(mill_index) == 1
         if (best_mill(mill_index,value_index) > E_limit) | (best_mill(mill_index,value_index) < -E_limit)
            best_mill(mill_index,value_index) = efm_data_matrix(2,mill_index,value_index);
            gain(mill_index,value_index) = 2;
            last_gain(mill_index) = 2;
         else
            gain(mill_index,value_index) = 1;
            last_gain(mill_index) = 1;
         end
      else
         if (best_mill(mill_index,value_index) > E_minit) | (best_mill(mill_index,value_index) < -E_minit)
	         best_mill(mill_index,value_index) = efm_data_matrix(2,mill_index,value_index);
	         gain(mill_index,value_index) = 2;
	         last_gain(mill_index) = 2;
         else
            gain(mill_index,value_index) = 1;
            last_gain(mill_index) = 1;
         end
      end
   end
end
%
%	Now we have the best V/m, create the Q independent "L" values
%
L = l_matrix*best_mill;
aircraft_K_matrix = inv(k_matrix)*L;
%aircraft_K_matrix = k_matrix*L;
aircraft_E_matrix(1:3,:) = aircraft_K_matrix(1:3,:);
%
%   Now fake Q
%
aircraft_E_matrix(4,:) = 0;
%
%	Now calculate the slack value and magnitude
%
quality(how_big) = 0;
factor_it = 2/pi;
magE = aircraft_E_matrix(1,:).*aircraft_E_matrix(1,:) + aircraft_E_matrix(2,:).*aircraft_E_matrix(2,:) + aircraft_E_matrix(3,:).*aircraft_E_matrix(3,:);
magQ = aircraft_E_matrix(4,:).*aircraft_E_matrix(4,:);
quality = atan2(magE,magQ)*factor_it;
aircraft_E_matrix(6,:) = aircraft_K_matrix(4,:);
aircraft_E_matrix(5,:) = sqrt(magE);
