function [efm_cal_matrix] = load_cal_matrix(file_name, aircraft_mill_number);
%        [efm_cal_matrix] = load_cal_matrix(file_name, aircraft_mill_number)
%
%	This routine loads the calibration matrix for all mills and then creates
%	the appropriate calibration matrix for the given set of mills on the aircraft
%
%	Inputs:
%		file_name = file of calibration data
%		aircraft_mill_number = the serial # of each mill on the aircraft
%										in order (PD, PU, SD, SU, AD, AU)
%
%	Outputs:
%		efm_cal_matrix = the conversion from V to E at the mills (12,2)
%

%
%	Open file
%
fid1 = fopen(file_name,'r');
%
%	get mill #'s
%
line = fgetl(fid1);
if line(1) ~= 'V'
   error('File in wrong format');
end
the_scale = line(2);
[mills, mill_count] = sscanf(line(4:end),'%d');
mills
%
%	Now read the calibration data
%
line = fgetl(fid1);
line_index = 1;
while line(1) ~= 'V'
   if the_scale == 'S'
      [sensitive_cal_data(:,line_index),count2] = sscanf(line,'%f');
   else
      [insensitive_cal_data(:,line_index),count2] = sscanf(line,'%f');
   end
   if count2 ~= mill_count+1
      error('File format error (mill count error)');
   end
   line = fgetl(fid1);
   line_index = line_index + 1;
end
the_scale = line(2);
line_index = 1;
line = fgetl(fid1);
while line(1) ~= 'V'
   if the_scale == 'S'
      [sensitive_cal_data(:,line_index),count2] = sscanf(line,'%f');
   else
      [insensitive_cal_data(:,line_index),count2] = sscanf(line,'%f');
   end
   if count2 ~= mill_count+1
      error('File format error (mill count error)');
   end
   line = fgetl(fid1);
   if line == -1
      break;
   end
   line_index = line_index + 1;
end
%
%	Now that we have the data, figure out which mills are where, and
%	determine the calibration values
%
efm_cal_matrix(12,2) = 0;
aircraft_mill_count = length(aircraft_mill_number);
aircraft_mill_number
for aircraft_mill_index=1:aircraft_mill_count
   cal_mill_count = 1;
   while mills(cal_mill_count) ~= aircraft_mill_number(aircraft_mill_index)
      cal_mill_count = cal_mill_count + 1;
      if cal_mill_count > mill_count
         error('Could not find a/c mill in cal data');
      end
   end
   %
   %	Now we have found the mill, do the cal
   %
   efm_cal_matrix(aircraft_mill_index,:) = polyfit(sensitive_cal_data(cal_mill_count+1,:), sensitive_cal_data(1,:),1);
   efm_cal_matrix(aircraft_mill_index+aircraft_mill_count,:) = polyfit(insensitive_cal_data(cal_mill_count+1,:),insensitive_cal_data(1,:), 1);
end
