function [efm_data_matrix, time_array, mill_array, N, summary_data, summary_count] = load_efm_data(file_count, file_list, base_directory, pps, start_string, seconds);
%        [efm_data_matrix, time_array, mill_array, N, summary_data, summary_count] = 
%				load_efm_data(file_count, file_list, directory, pps, start_string, seconds);
%
%       NOTE: THIS ROUTINE HAS BEEN MORE OR LESS REPLACED WITH sload_efm_data THAT FIXES
%       MANY OF THE PROBLEMS ASSOCIATED WITH load_efm_data.....
%
%
%	This routine loads a boatload of efm data into two arrays, one for the data
%	and one for time.  It will use "resample" to take the data from 50 samples per second to the
%	value set in pps.  Note that "resample" is set to NOT filter the data.
%
%	Inputs:
%		file_count = # input files
%		file_list(file_count,?) = char string array of input files
%		directory = char of base directory to find files (default: current directory)
%		pps = how many points per second in the output (default: all 50)
%		start_string = string of start time, format: 'dd-mmm-yyyy hh:mm:ss' (default: start of data)
%		seconds = # of seconds for data (default: all data)
%	Outputs:
%		efm_data_matrix = the 2 x 6 x N (depending on the skip & seconds values) array of efm data
%		time = time array for the points (in dateform format)
%		mill_array = array of mill ID's
%		N = # of points in the array of efm & time
%		summary_data = struct of summary data (optional)
%			GPStime = GPS time of summary data in dateform format
%			PCtime = PC time of summary data in dateform format
%			GPSTimerActive = not sure
%			GPSfailed = not sure
%			GPSIOStatus = unknown
%		summary_count = # of the summary data structures (optional)
%
%		There are a max of 50 points per second
%

%
%	Set any defaults
%
T0 = clock;
format compact;
'Setting defaults'
default_size = 91000;
if ~exist('seconds','var')
   seconds = 0;
end
if ~exist('pps','var')
   pps = 50;
end
if ~exist('cut_off','var')
   cut_off = 0;
end
if ~exist('order','var')
   order = 2;
end
if exist('start_string','var')
   first_time = datenum(start_string);
else
   first_time = 0;
end
%
%	Init the data
%
'Init data'
summary_count = 0;
T0 = clock;
Ntot = seconds*pps;
time_base = 'XXX';
if Ntot ~= 0
   efm_data_1s(Ntot) = 0;
   efm_data_1i(Ntot) = 0;
   efm_data_2s(Ntot) = 0;
   efm_data_2i(Ntot) = 0;
   efm_data_3s(Ntot) = 0;
   efm_data_3i(Ntot) = 0;
   efm_data_4s(Ntot) = 0;
   efm_data_4i(Ntot) = 0;
   efm_data_5s(Ntot) = 0;
   efm_data_5i(Ntot) = 0;
   efm_data_6s(Ntot) = 0;
   efm_data_6i(Ntot) = 0;
   time(Ntot) = 0;
   mask_it(Ntot) = 0;
else
   efm_data_1s(default_size) = 0;
   efm_data_1i(default_size) = 0;
   efm_data_2s(default_size) = 0;
   efm_data_2i(default_size) = 0;
   efm_data_3s(default_size) = 0;
   efm_data_3i(default_size) = 0;
   efm_data_4s(default_size) = 0;
   efm_data_4i(default_size) = 0;
   efm_data_5s(default_size) = 0;
   efm_data_5i(default_size) = 0;
   efm_data_6s(default_size) = 0;
   efm_data_6i(default_size) = 0;
   time(default_size) = 0;
   mask_it(default_size) = 0;
end
last_block = init_efm_struct;
efm_block_current = init_efm_struct;
efm_block_next = init_efm_struct;
counts_2_volts = 5.0/65536.0;	% 5 volts / 65,536 bits
%
%	Determine the first time
%
%
%	Open file
%
'Open file'
N=0;
block_index = 1;
last_time = 0;
for i=1:6
    mill_array(i) = 0;
    new_mill_array(i) = 0;
end
for i=1:file_count
   %
   %	Open next file
   %
   'Opening next file'
   strcat(base_directory,'\',file_list(i,:))
   fid1 = fopen(strcat(base_directory,'\',file_list(i,:)),'r');
	file_block_count = 0;
   %
   %	Determine the nominal time of the data
   %
   file_time = sscanf(file_list(i,:),'EFM_LZ_V%f_%d-%d-%dT%d-%d-%d');
   %
   %	Read first block of data
   %
   efm_block_current = read_efm_block(fid1, efm_block_current);
   %
   %	We will make a radical assumption: that the mills
   %		will not change in mid-flight.  
   %
   for mill_index=1:6
      new_mill_array(mill_index) = bitshift(bitand(efm_block_current.efmrecord(mill_index).header(3),248),-3);
   end
   if i ~= 1
      for mill_index=1:6
          if new_mill_array(mill_index) ~= mill_array(mill_index)
              beep;
              new_mill_array
              mill_array
              what_now = input('Mills Changed in Mid-Flight, keep (o)ld or (n)ew?','s');
              if what_now(1) == 'n'
                  mill_array = new_mill_array;
                  'Using new values'
                  mill_array
              else
                  'Using old values'
                  mill_array
              end
              break;
          end
      end
   end
   while efm_block_current.version ~= 0
   	%
   	%	See if the data times match the nominal time of the file
   	%
   	file_date = datenum(file_time(2),file_time(3),file_time(4),file_time(5),file_time(6),file_time(7));
      GPS_time = efm_block_current.datetime;
      datestr(GPS_time)
      if abs(efm_block_current.datetime-file_date) > 3e-2
      	%
      	%	The GPS time is bad, try the pctime
      	%
      	pctime = datenum(efm_block_current.pcUTC.tm_year+1900, efm_block_current.pcUTC.tm_mon+1, efm_block_current.pcUTC.tm_mday,  efm_block_current.pcUTC.tm_hour, efm_block_current.pcUTC.tm_min, efm_block_current.pcUTC.tm_sec);
      	if abs(pctime-file_date) > 3e-2
      	   %
      	   %	PC time is bad, just use the file name as the base time
      	   %
            efm_block_current.datetime = file_date + file_block_count*1.157e-5;
            if time_base ~= 'FIL'
               strcat('Using file name as base time ','file_date:',datestr(file_date),' GPS_date:',datestr(GPS_time),' PC_date',datestr(pctime))
               time_base = 'FIL';
            end
      	else
            efm_block_current.datetime = pctime;
            if time_base ~= 'PC '
               strcat('Using pc time as base time ','file_date:',datestr(file_date),' GPS_date:',datestr(GPS_time),' PC_date:',datestr(pctime))
               time_base = 'PC ';
            end
      	end
      else
         if time_base ~= 'GPS'
            strcat('Using GPS as base time ','file_date:',datestr(file_date),' GPS_date:',datestr(GPS_time),' PC_date:',datestr(pctime))
            time_base = 'GPS';
         end
      end
	   summary_count = summary_count + 1;
	   summary_data(summary_count).GPSTime = efm_block_current.datetime;
	   summary_data(summary_count).PCTime = datenum(efm_block_current.pcUTC.tm_year+1900, efm_block_current.pcUTC.tm_mon+1, efm_block_current.pcUTC.tm_mday,  efm_block_current.pcUTC.tm_hour, efm_block_current.pcUTC.tm_min, efm_block_current.pcUTC.tm_sec);
	   summary_data(summary_count).GPSTimerActive = efm_block_current.GPSTimerActive;
	   summary_data(summary_count).GPSfailed = efm_block_current.GPSfailed;
      summary_data(summary_count).GPSIOStatus = efm_block_current.GPSIOStatus;
      summary_data(summary_count).LLAgpspkt = efm_block_current.LLAgpspkt;
      summary_data(summary_count).VELgpspkt = efm_block_current.VELgpspkt;
      %
      %	We have data in the block
      %
      if efm_block_current.datetime >= first_time
		   %
		   %	See if there is a time gap in the data
		   %
         if last_block.datetime ~= 0
            delta_seconds = round((efm_block_current.datetime-last_block.datetime)*86400);
            if delta_seconds > 1.0
               strcat('Gap ',' pre:',datestr(last_block.datetime),' Post:',datestr(efm_block_current.datetime))
               %
               %	Add a set of 0 value data for the data gap
               %	But only up to a minute of gap (to save memory)
               %
               if delta_seconds > 30
                  delta_jump = 30;
               else
                  delta_jump = delta_seconds;
               end
               for second_jump=1:(delta_jump-1)
                  for block_index=1:50
                     N = N + 1;
            			if (Ntot == 0) & (N > default_size)
               			'Increasing default size'
               			default_size = default_size*2
   							efm_data_1s(default_size) = 0;
   							efm_data_1i(default_size) = 0;
   							efm_data_2s(default_size) = 0;
   							efm_data_2i(default_size) = 0;
   							efm_data_3s(default_size) = 0;
   							efm_data_3i(default_size) = 0;
   							efm_data_4s(default_size) = 0;
   							efm_data_4i(default_size) = 0;
   							efm_data_5s(default_size) = 0;
   							efm_data_5i(default_size) = 0;
   							efm_data_6s(default_size) = 0;
							   efm_data_6i(default_size) = 0;
                        time(default_size) = 0;
                        mask_it(default_size) = 0;
			            end
			            efm_data_1s(N) = 0.0;
            			efm_data_1i(N) = 0.0;
            			efm_data_2s(N) = 0.0;
            			efm_data_2i(N) = 0.0;
            			efm_data_3s(N) = 0.0;
            			efm_data_3i(N) = 0.0;
            			efm_data_4s(N) = 0.0;
            			efm_data_4i(N) = 0.0;
            			efm_data_5s(N) = 0.0;
            			efm_data_5i(N) = 0.0;
            			efm_data_6s(N) = 0.0;
                     efm_data_6i(N) = 0.0;
                     mask_it(N) = 1;
			         	time(N) = last_block.datetime + ((block_index-1) + second_jump*50)*2.3148e-7;
                  end
               end
            end
            if delta_seconds < 1.0
               %
               %	Jump back in time
               %
               strcat('Reverse ',' pre:',datestr(last_block.datetime),' Post:',datestr(efm_block_current.datetime))
               delta_seconds
               N
               N = N + (delta_seconds-1)*50;
               N
            end
         end
	      for block_index=1:50
            N = N + 1;
            if (Ntot == 0) & (N > default_size)
               'Increasing default size'
               default_size = default_size*2
   				efm_data_1s(default_size) = 0;
   				efm_data_1i(default_size) = 0;
   				efm_data_2s(default_size) = 0;
   				efm_data_2i(default_size) = 0;
   				efm_data_3s(default_size) = 0;
   				efm_data_3i(default_size) = 0;
   				efm_data_4s(default_size) = 0;
   				efm_data_4i(default_size) = 0;
   				efm_data_5s(default_size) = 0;
   				efm_data_5i(default_size) = 0;
   				efm_data_6s(default_size) = 0;
				   efm_data_6i(default_size) = 0;
               time(default_size) = 0;
               mask_it(default_size) = 0;
            end
            if time_base == 'FIL'
                if N > 600435
                    efm_block_current.efmrecord.sensitive;
                end
                block_index;
            end
            efm_data_1s(N) = efm_block_current.efmrecord(1).sensitive(block_index);
            efm_data_1i(N) = efm_block_current.efmrecord(1).insensitive(block_index);
            efm_data_2s(N) = efm_block_current.efmrecord(2).sensitive(block_index);
            efm_data_2i(N) = efm_block_current.efmrecord(2).insensitive(block_index);
            efm_data_3s(N) = efm_block_current.efmrecord(3).sensitive(block_index);
            efm_data_3i(N) = efm_block_current.efmrecord(3).insensitive(block_index);
            efm_data_4s(N) = efm_block_current.efmrecord(4).sensitive(block_index);
            efm_data_4i(N) = efm_block_current.efmrecord(4).insensitive(block_index);
            efm_data_5s(N) = efm_block_current.efmrecord(5).sensitive(block_index);
            efm_data_5i(N) = efm_block_current.efmrecord(5).insensitive(block_index);
            efm_data_6s(N) = efm_block_current.efmrecord(6).sensitive(block_index);
            efm_data_6i(N) = efm_block_current.efmrecord(6).insensitive(block_index);
            mask_it(N) = 0;
         	time(N) = efm_block_current.datetime + (block_index-1)*2.3148e-7;
      	end
      end
      %
      %	Get the nex block
      %
      last_block = efm_block_current;
      file_block_count = file_block_count + 1;
      efm_block_current = read_efm_block(fid1, efm_block_current);
   end
   %
   %	Get the next file
   %
   fclose(fid1);
end
%
%	Now we have fallen off the end of the data, make sure the efm and time
%	data are sized correctly
%
'Fell off end of data'
N
Ntot = ceil(N*pps/50)
efm_data_matrix(2,6,Ntot) = 0;
time_array(Ntot) = 0;
dummy_array(Ntot) = 0;
%
%	Now make and use the filter, remembering to halve the order since the filtfilt
%	doubles the order of the filter
%
%[b,a] = butter(ceil(order*.5),cut_off/25);
%'Doing filter'
%efm_data_1s = filtfilt(b,a,efm_data_1s(1:N));
%efm_data_1i = filtfilt(b,a,efm_data_1i(1:N));
%efm_data_2s = filtfilt(b,a,efm_data_2s(1:N));
%efm_data_2i = filtfilt(b,a,efm_data_2i(1:N));
%efm_data_3s = filtfilt(b,a,efm_data_3s(1:N));
%efm_data_3i = filtfilt(b,a,efm_data_3i(1:N));
%efm_data_4s = filtfilt(b,a,efm_data_4s(1:N));
%efm_data_4i = filtfilt(b,a,efm_data_4i(1:N));
%efm_data_5s = filtfilt(b,a,efm_data_5s(1:N));
%efm_data_5i = filtfilt(b,a,efm_data_5i(1:N));
%efm_data_6s = filtfilt(b,a,efm_data_6s(1:N));
%efm_data_6i = filtfilt(b,a,efm_data_6i(1:N));
'Doing resample'
d = gcd(pps,50);
p = pps/d;
q = 50/d;
dummy_array = resample(efm_data_1s(1:N),p,q,0);
Ntot = length(dummy_array)
for index=1:Ntot
   efm_data_matrix(1,1,index) = dummy_array(index);
end
dummy_array = resample(efm_data_1i(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(2,1,index) = dummy_array(index);
end
dummy_array = resample(efm_data_2s(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(1,2,index) = dummy_array(index);
end
dummy_array = resample(efm_data_2i(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(2,2,index) = dummy_array(index);
end
dummy_array = resample(efm_data_3s(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(1,3,index) = dummy_array(index);
end
dummy_array = resample(efm_data_3i(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(2,3,index) = dummy_array(index);
end
dummy_array = resample(efm_data_4s(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(1,4,index) = dummy_array(index);
end
dummy_array = resample(efm_data_4i(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(2,4,index) = dummy_array(index);
end
dummy_array = resample(efm_data_5s(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(1,5,index) = dummy_array(index);
end
dummy_array = resample(efm_data_5i(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(2,5,index) = dummy_array(index);
end
dummy_array = resample(efm_data_6s(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(1,6,index) = dummy_array(index);
end
dummy_array = resample(efm_data_6i(1:N),p,q,0);
for index=1:Ntot
   efm_data_matrix(2,6,index) = dummy_array(index);
end
time_array = resample(time(1:N),p,q,0);
mask_it_rs = resample(mask_it(1:N),p,q,0);
N = length(time_array)
'Convert to Volts'
efm_data_matrix = efm_data_matrix*counts_2_volts;
%
%	Now mask off the times when there was no data
%
for i=1:N
   if mask_it_rs(i) == 1
      efm_data_matrix(:,:,i) = NaN;
   end
end
etime(clock,T0)




