function [file_list,file_count, directory] = load_file_names(directory);
%		[file_list, file_count, directory] = load_file_names(directory)
%
%	This routine finds all efm data files in a given directory
%	The names need to follow the standard format:
%		EFM_LZ_V*.dat
%	where the * contains the date/time information
%
%	Input:
%		directory = directory where efm data resides
%
%	Output:
%		file_list = string array of sorted data files
%		file_count = number of data files found
%		directory = directory where efm data resides
%

%
%	First get the data
%
file_count = 0;
the_total = dir(directory);
index_max = length(the_total);
for index = 1:index_max
   %
   %	We look at it only if it is not a directory
   %
   if the_total(index).isdir == 0
      %
      %	Now we only get names that fit
      %
      if strcmp(the_total(index).name(1:8),'EFM_LZ_V') == 1
         file_count = file_count + 1;
         file_list_s(file_count).name = the_total(index).name;
      end
   end
end
%
%	Now we have the names, the must be sorted by time
%	first convert to cell and then sort
%
file_list_c = struct2cell(file_list_s);
file_list = char(sort(file_list_c));
