function [radar_volume, vir0c] = load_radar_volume(file_name);
%
%  function [radar_volume, VIR0C] = load_radar_volume(file_name);
%
%  This routine loads the radar volume in the file 'file_name'
%

%
%  Set the parameters
%
x_size = 226;
y_size = 226;
z_size = 21;
vir0c_level = 5;
radar_volume(x_size, y_size, z_size) = 0;
vir0c(x_size, y_size) = 0;
total_size = x_size*y_size*z_size;
%
%  Open the file
%
fid = fopen(file_name,'r');
[data, count] = fread(fid, inf, 'int16');
count;
if count ~= total_size
   error('Wrong size data file');
end
%
%  Now make the radar volume and VIR-0C dataset
%
l=1
for i=1:226
   for j=1:226
      for k=1:21
         radar_volume(i,j,k) = data(l);
         if radar_volume(i,j,k) == -32768
            radar_volume(i,j,k) = NaN;
         else
            radar_volume(i,j,k) = radar_volume(i,j,k)*0.01;
         end
         if k > vir0c_level
            the_mod_data = data(l)*0.01;
            if the_mod_data < -10
               the_mod_data = 0;
            else
               the_mod_data = the_mod_data + 10;
            end
            vir0c(i,j) = vir0c(i,j) + the_mod_data;
         end
         l=l+1;
      end
   end
end
%
%  Fix gap in data due north of radar
%  (temp hardwired fix)
%
for i=76:226
   j=76;
   if vir0c(i,j-1) ~= 0
      vir0c(i,j) = mean([vir0c(i,j-1) vir0c(i,j+1)]);
   else
      vir0c(i,j) = vir0c(i,j-2)/3 + vir0c(i,j+1)*2/3;
      vir0c(i,j-1) = vir0c(i,j-2)*2/3 + vir0c(i,j+1)/3;
   end
   for k=1:21
      if radar_volume(i,j-1,k) ~= 0
         radar_volume(i,j,k) = mean([radar_volume(i,j-1,k) radar_volume(i,j+1,k)]);
      else
         radar_volume(i,j,k) = radar_volume(i,j-2,k)/3 + radar_volume(i,j+1,k)*2/3;
         radar_volume(i,j-1,k) = radar_volume(i,j-2,k)*2/3 + radar_volume(i,j+1,k)/3;
      end
   end
end
%
%  That is the end of the fix
%
fclose(fid);
