function [Np,fid] = output_2_ascii(time,mill_E_matrix,aircraft_E_matrix,earth_E_matrix,orientation_matrix,location_matrix,pos_matrix,gain_matrix,file_name_base);
%   function [Np, fid] = output_2_ascii(time, mill_E_matrix, aircraft_E_matrix, earth_E_matrix, orientation_matrix, location_matrix, 
%       pos_matrix, gain_matrix, file_name_base);
%
%	This routine outputs all the data to a file
%
%	Inputs:
%       time = the N array of datenum time values
%       mill_E_matrix = the (2,6,N) matrix of mill electric field values
%		orientation_matrix = the (3,N) matrix of aircraft orientation (roll, pitch, heading)
%		location_matrix = the (5,N) matrix of aircraft location (lat, lon, alt, trk, gspd)
%		pos_matrix = the (6,N) matrix of aircraft pos data (X_acc, Y_acc, Z_acc, Ice_LWC, FSSP_LWC, 2D_conc)
%		gain_matrix = the (6,N) matrix of gains used in the calculations (1=sensitive, 2=insensitive)
%       file_name_base = output ASCII file name base (rest of file name will be the time of first data)
%
%   Outputs:
%       Np = # of lines in the output file
%       fid = file ID of the output file
%

%
%   First, find the time of the first point and open file
%
t0 = floor(time(1));
timestr = datestr(t0)
aircraft_file_name = strcat(file_name_base,timestr,'_aircraft.asc')
earth_file_name = strcat(file_name_base,timestr,'_earth.asc')
sensitive_file_name = strcat(file_name_base,timestr,'_sens.asc')
insensitive_file_name = strcat(file_name_base,timestr,'_insens.asc')
orient_file_name = strcat(file_name_base,timestr,'_orient.asc')
location_file_name = strcat(file_name_base,timestr,'_location.asc')
pos_file_name = strcat(file_name_base,timestr,'_pos.asc')
gain_file_name = strcat(file_name_base,timestr,'_gain.asc')
fid(1) = fopen(aircraft_file_name,'w');
fid(2) = fopen(earth_file_name,'w');
fid(3) = fopen(sensitive_file_name,'w');
fid(4) = fopen(insensitive_file_name,'w');
fid(5) = fopen(orient_file_name,'w');
fid(6) = fopen(location_file_name,'w');
fid(7) = fopen(pos_file_name,'w');
fid(8) = fopen(gain_file_name,'w');
N = length(time);
%
%   Get output time format (seconds from file name date)
%
seconds(N) = 0;
for i=1:N
    seconds(i) = (time(i)-t0)*86400;
   %
   %   Now put the data to the file
   %
   fprintf(fid(1),'%8.1f\t%e\t%e\t%e\t%e\t%e\t%e\n',seconds(i),aircraft_E_matrix(1,i),aircraft_E_matrix(2,i),aircraft_E_matrix(3,i),aircraft_E_matrix(4,i),aircraft_E_matrix(5,i),aircraft_E_matrix(6,i));
   fprintf(fid(2),'%8.1f\t%e\t%e\t%e\t%e\t%e\t%e\n',seconds(i),earth_E_matrix(1,i),earth_E_matrix(2,i),earth_E_matrix(3,i),earth_E_matrix(4,i),earth_E_matrix(5,i),earth_E_matrix(6,i));
   fprintf(fid(3),'%8.1f\t%e\t%e\t%e\t%e\t%e\t%e\n',seconds(i),mill_E_matrix(1,1,i),mill_E_matrix(1,2,i),mill_E_matrix(1,3,i),mill_E_matrix(1,4,i),mill_E_matrix(1,5,i),mill_E_matrix(1,6,i));
   fprintf(fid(4),'%8.1f\t%e\t%e\t%e\t%e\t%e\t%e\n',seconds(i),mill_E_matrix(2,1,i),mill_E_matrix(2,2,i),mill_E_matrix(2,3,i),mill_E_matrix(2,4,i),mill_E_matrix(2,5,i),mill_E_matrix(2,6,i));
   fprintf(fid(5),'%8.1f\t%6.2f\t%6.2f\t%6.2f\n',seconds(i),orientation_matrix(1,i),orientation_matrix(2,i),orientation_matrix(3,i));
   fprintf(fid(6),'%8.1f\t%8.3f\t%8.3f\t%7.1f\t%5.1f\t%6.2f\n',seconds(i),location_matrix(1,i),location_matrix(2,i),location_matrix(3,i),location_matrix(4,i),location_matrix(5,i));
   fprintf(fid(7),'%8.1f\t%f\t%f\t%f\t%f\t%f\t%f\n',seconds(i),pos_matrix(1,i),pos_matrix(2,i),pos_matrix(3,i),pos_matrix(4,i),pos_matrix(5,i),pos_matrix(6,i));
   fprintf(fid(8),'%8.1f\t%d\t%d\t%d\t%d\t%d\t%d\n',seconds(i),gain_matrix(1,i),gain_matrix(2,i),gain_matrix(3,i),gain_matrix(4,i),gain_matrix(5,i),gain_matrix(6,i));
end
%
%  Now close all the files
%
for i=1:8
    fclose(fid(i));
end
%
%   That is all!
%
return;
