function [plot_handles] = plot_XYZ_data(pos_location_matrix, time, plot_size, start_string, delta_seconds, window_width,do_grid);
%	function [plot_handles] = plot_pos_data(pos_location_matrix, time, plot_size, start_string, delta_seconds, 
%     window_width, do_grid)
%
%	Input:
%		pos_location_matrix = matrix of aircraft location data
%		time = the time array (in datetick format)
%		plot_size = array of minimum Lat, Long, & Alt size for the plots 
%		start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%		delta_seconds = how much of the data to plot (default or 0: all data)
%				Note: if start_string is a char string, delta_seconds units are seconds,
%				if start_string is an index, then delta_seconds is in index #'s
%		window_width = how many seconds per plot window (default or 0: 30 minutes)
%				Note: if start_string is a char string, window_width units are seconds,
%				if start_string is an index, then window_width is in index #'s
%     do_grid = character string of 'y', 'n', and/or 't' do we print the grid (y, n) and/or do
%           we print time ticks (t)
%
%	Output:
%		plot_handles = the handles to all of the plots
%
max_size = length(time);
if ~exist('start_string','var')
   first_time = time(1);
else
   if ischar(start_string) == 0
      if first_time < 1
         first_time = 1;
      end
      first_time = time(start_string);
   else
      first_time = datenum(start_string);
   end
end
if ~exist('delta_seconds','var')
   last_time = time(length(time));
else
   if delta_seconds == 0
      last_time = time(length(time));
   else
      if ischar(start_string) == 0
         last_time = time(delta_seconds+start_string);
      else
         last_time = first_time + delta_seconds*1.1574e-5;
      end
   end
end
if ~exist('window_width','var')
   window_width = 30*60;
else
   if window_width == 0
      window_width = 30*60;
   else
      if ischar(start_string) == 0
         window_width = (time(window_width) - time(1))*86400;
      end
   end
end
if ~exist('plot_size','var')
   plot_size = [0, 0, 0];
end
%
%	Determine where to start & end the plots
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_size
      error('Fell off end of A/C data before hitting first time');
   end
end
first_pos_index = i;
i=first_pos_index;
while time(i) < last_time
   i = i + 1;
   if i > max_size
      i = max_size;
      break;
   end
end
last_pos_index = i
window_start_time = first_time;
window_start_index = first_pos_index;
window_index = 0;
if window_width > 120
   dateform = 15;
else
   dateform = 13;
end
do_time_tick = 'n';
if size(findstr(do_grid,'t')) ~= 0
   do_time_tick = 'y';
elseif size(findstr(do_grid,'T')) ~= 0
   do_time_tick = 'y';
end
do_time_tick
do_grid
while window_start_time < last_time
   time_end = window_start_index;
   window_end_time = window_start_time + (window_width*1.157407e-5);
   while time(time_end) <= window_end_time
      time_end = time_end + 1;
      if time_end == max_size
         break;
      end
   end
   time_end = time_end - 1;
   %
   %	Make sure we don't plot any small windows
   %
   if last_time - window_end_time < 0.1*window_width*1.157407e-5
      window_end_time = last_time;
   end
   %
   %	Now plot aircraft location data
   %
   window_index = window_index + 1;
   plot_handles(window_index) = figure;
   axes('position',[0.1 0.1 0.7 0.7]);
   load coast;
   plot(pos_location_matrix(2,window_start_index:time_end),pos_location_matrix(1,window_start_index:time_end));
   text(pos_location_matrix(2,window_start_index),pos_location_matrix(1,window_start_index),'s');
   text(pos_location_matrix(2,time_end),pos_location_matrix(1,time_end),'e');
   if do_time_tick == 'y'
      %
      %  Determine the time tick locations
      %
      delta_index = time_end - window_start_index;
      delta_seconds = (time(time_end) - time(window_start_index))*24*60*60;
      time_tick = 0;
      if delta_seconds > 1
         tick_time = 1;
      end
      if delta_seconds > 9
         tick_time = 5;
      end
      if delta_seconds > 59
         tick_time = 10;
      end
      if delta_seconds > 299
         tick_time = 60;
      end
      if delta_seconds > 1199
         tick_time = 240;
      end
      if delta_seconds > 5999
         tick_time = 1200;
      end
      delta_tick_index = tick_time*delta_index/delta_seconds
      for j=window_start_index+delta_tick_index:delta_tick_index:time_end
         text(pos_location_matrix(2,round(j)),pos_location_matrix(1,round(j)),'+');
      end
   end
   if (plot_size(1) == 0) & (plot_size(2) == 0 ) 
      axis equal;
   else
      current_limits = axis;
      add_2_lat = plot_size(1) - (current_limits(2)-current_limits(1));
      if add_2_lat > 0
         current_limits(1) = current_limits(1) - add_2_lat/2;
         current_limits(2) = current_limits(2) + add_2_lat/2;
      end
      add_2_lon = plot_size(2) - (current_limits(4)-current_limits(3));
      if add_2_lon > 0
         current_limits(3) = current_limits(3) - add_2_lon/2;
         current_limits(4) = current_limits(4) + add_2_lon/2;
      end
      axis(current_limits);
   end
   ylabel('Latitude ');
   xlabel('Longitude ');
   box on;
   V = axis;
   if size(findstr(do_grid,'y')) ~= 0
      grid on;
   elseif size(findstr(do_grid,'Y')) ~= 0
      grid on;
   end
   axes('position',[0.8 0.1 0.2 0.7]);
   plot(0.001*pos_location_matrix(3,window_start_index:time_end),pos_location_matrix(1,window_start_index:time_end));
   text(0.001*pos_location_matrix(3,window_start_index),pos_location_matrix(1,window_start_index),'s');
   text(0.001*pos_location_matrix(3,time_end),pos_location_matrix(1,time_end),'e');
   if do_time_tick == 'y'
      for j=window_start_index+delta_tick_index:delta_tick_index:time_end
         text(0.001*pos_location_matrix(3,round(j)),pos_location_matrix(1,round(j)),'+');
      end
   end
   axis tight;
   box on;
   V2 = axis;
   xlabel('Altitude (km)');
   axis([V2(1) V2(2) V(3) V(4)]);
   if plot_size(3) ~= 0
      current_limits = axis;
      add_2_alt = plot_size(3) - (current_limits(2)-current_limits(1));
      if add_2_alt > 0
         current_limits(1) = current_limits(1) - add_2_alt/2;
         current_limits(2) = current_limits(2) + add_2_alt/2;
      end
      axis(current_limits);
   end
   set(gca,'yticklabel',[]);
   if size(findstr(do_grid,'y')) ~= 0
      grid on;
   elseif size(findstr(do_grid,'Y')) ~= 0
      grid on;
   end
   axes('position',[0.1 0.8 0.7 0.2]);
   plot(pos_location_matrix(2,window_start_index:time_end),0.001*pos_location_matrix(3,window_start_index:time_end));
   text(pos_location_matrix(2,window_start_index),0.001*pos_location_matrix(3,window_start_index),'s');
   text(pos_location_matrix(2,time_end),0.001*pos_location_matrix(3,time_end),'e');
   if do_time_tick == 'y'
      for j=window_start_index+delta_tick_index:delta_tick_index:time_end
         text(pos_location_matrix(2,round(j)),0.001*pos_location_matrix(3,round(j)),'+');
      end
   end
   axis tight;
   V3 = axis;
   box on;
   ylabel('Altitude (km)');
   axis([V(1) V(2) V3(3) V3(4)]);
   current_limits = axis;
   if plot_size(3) ~= 0
      add_2_alt = plot_size(3) - (current_limits(4)-current_limits(3));
      if add_2_alt > 0
         current_limits(3) = current_limits(3) - add_2_alt/2;
         current_limits(4) = current_limits(4) + add_2_alt/2;
      end
      axis(current_limits);
   end
   set(gca,'xticklabel',[]);
   text(current_limits(2),current_limits(3)+(current_limits(4)-current_limits(3))*0.15, datestr(time(time_end),13));
   text(current_limits(2),current_limits(3)+(current_limits(4)-current_limits(3))*0.3, datestr(time(time_end),1));
   if do_time_tick == 'y'
      my_string = sprintf('\\Delta t:%d s',tick_time);
      text(current_limits(2),current_limits(3)+(current_limits(4)-current_limits(3))*0.5, my_string);
   end
   text(current_limits(2),current_limits(4)-(current_limits(4)-current_limits(3))*0.15, datestr(time(window_start_index),1));
   text(current_limits(2),current_limits(4)-(current_limits(4)-current_limits(3))*0.3, datestr(time(window_start_index),13));
   if size(findstr(do_grid,'y')) ~= 0
      grid on;
   elseif size(findstr(do_grid,'Y')) ~= 0
      grid on;
   end
   %
   %	Prepare for next group
   %
   window_start_index = time_end + 1;
   window_start_time = window_end_time;
end
