function [plot_handles] = plot_pos_data(pos_orientation_matrix, pos_location_matrix, pos_data_matrix, time, plot_components, start_string, delta_seconds, window_width,orientation);
%	function [plot_handles] = plot_pos_data(pos_orientation_matrix, pos_location_matrix, pos_data_matrix, time, 
%		plot_components, start_string,total_seconds, window_width, orientation)
%
%	Input:
%		pos_orientation_matrix = matrix of aircraft orientation data
%		pos_location_matrix = matrix of aircraft location data
%		pos_data_matrix = matrix of aircraft pos data (LWC, etc.)
%		time = the time array (in datetick format)
%		plot_components = character string of which components to plot as a series of x's or X's, 
%			(x or X means plot that component, space means don't, order is Roll, Pitch, Heading, Latitude,
%        Longitude, Altitude, Track, Ground Speed, X_Acc, Y_Acc, Z Acc, ICE, FSSP, 2D, XYZ plot
%			uppercase means plot with grid, lowercase without grid
%		start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%		total_seconds = how much of the data to plot (default or 0: all data)
%				Note: if start_string is a char string, total_seconds units are seconds,
%				if start_string is an index, then total_seconds is in index #'s
%		window_width = how many seconds per plot window (default or 0: 30 minutes)
%				Note: if start_string is a char string, window_width units are seconds,
%				if start_string is an index, then window_width is in index #'s
%     orientation = is one of 'landscape', 'portrait', 'rotated', or 'tall' (default 'tall').
%
%	Output:
%		plot_handles = the handles to all of the plots
%

%
%	Set any defaults that were not entered by the user
%
global g_time g_pos_orientation_matrix g_pos_location_matrix g_pos_data_matrix window_start_index time_end plot_count plot_number plot_count_2 plot_number_2 window_start_time window_end_time g_plot_components date_strings dateform the_title
g_time = time;
g_pos_orientation_matrix = pos_orientation_matrix;
g_pos_data_matrix = pos_data_matrix;
g_pos_location_matrix = pos_location_matrix;
g_plot_components = plot_components;
max_size = length(time);
if ~exist('start_string','var')
   first_time = time(1);
else
   if ischar(start_string) == 0
      if first_time < 1
         first_time = 1;
      end
      first_time = time(start_string);
   else
      first_time = datenum(start_string);
   end
end
if ~exist('delta_seconds','var')
   last_time = time(length(time));
else
   if delta_seconds == 0
      last_time = time(length(time));
   else
      if ischar(start_string) == 0
         last_time = time(delta_seconds+start_string);
      else
         last_time = first_time + delta_seconds*1.1574e-5;
      end
   end
end
if ~exist('window_width','var')
   window_width = 30*60;
else
   if window_width == 0
      window_width = 30*60;
   else
      if ischar(start_string) == 0
         window_width = (time(window_width) - time(1))*86400;
      end
   end
end
if ~exist('plot_components','var')
   plot_components = 'XXXXXXXXXXXXXXX';
end
if ~exist('orientation','var')
   orientation = 'tall';
end
%
%	Set up which components will be plotted
%
max_plots = length(plot_components);
plot_count = 0;
plot_count_3 = 0;
plot_count_4 = 0;
for index=1:max_plots
    if plot_components(index) ~= ' '
        if index < 9
            plot_count = plot_count + 1;
        end
        if index > 8
            if index == 15
                plot_count_3 = plot_count_3 + 1;
            else
                plot_count_4 = plot_count_4 + 1;
            end
        end
    end
end
%
%   Combine the two strip chart plots if there are too few items to plot
%
if plot_count+plot_count_4 < 8
    the_combine = plot_count+plot_count_4;
else
    the_combine = 0;
end
if max_plots ~= 15
   for index=max_plots+1:15
 	  plot_components(index) = ' ';
   end
end
%
%	Determine where to start & end the plots
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_size
      error('Fell off end of A/C data before hitting first time');
   end
end
first_pos_index = i;
i=first_pos_index;
while time(i) < last_time
   i = i + 1;
   if i > max_size
      i = max_size;
      break;
   end
end
last_pos_index = i
window_start_time = first_time;
window_start_index = first_pos_index;
window_index = 0;
if window_width > 120
   dateform = 15;
else
   dateform = 13;
end
while window_start_time < last_time
   %
   %	Plot aircraft orientation data in window
   %
   time_end = window_start_index;
   window_end_time = window_start_time + (window_width*1.157407e-5);
   %
   %	Make sure we don't plot any small windows
   %
   if last_time - window_end_time < 0.1*window_width*1.157407e-5
      window_end_time = last_time;
   end
   while time(time_end) <= window_end_time
      time_end = time_end + 1;
      if time_end >= max_size
          time_end = max_size;
         break;
      end
   end
   time_end = time_end - 1;
   %
   %	Now do the plots
   %
   if (plot_count > 0) & (time_end > window_start_index)
      window_index = window_index + 1;
      plot_handles(window_index) = figure;
      orient(plot_handles(window_index), orientation);
      plot_number = 1;
      window_start_index
      time_end
      if the_combine == 0 
          the_title = 'Aircraft Orientation/Location';
      else
          the_title = 'Aircraft Orientation/Location/POS Data';
          plot_count = the_combine;
      end
	   if plot_components(1) ~= ' '
		   subsubplot(1,plot_count,'Roll','deg',pos_orientation_matrix,plot_components(1));
	   end
	   if plot_components(2) ~= ' '
		   subsubplot(2, plot_count,'Pitch','deg',pos_orientation_matrix,plot_components(2));
	   end
	   if plot_components(3) ~= ' '
		   subsubplot(3, plot_count,'Heading','deg',pos_orientation_matrix,plot_components(3));
	   end
      if plot_components(4) ~= ' '
		   subsubplot(1, plot_count,'Lat','deg',pos_location_matrix,plot_components(4));
      end
      if plot_components(5) ~= ' '
		   subsubplot(2, plot_count,'Lon','deg',pos_location_matrix,plot_components(5));
	   end
      if plot_components(6) ~= ' '
		   subsubplot(3, plot_count,'Alt','m',pos_location_matrix,plot_components(6));
	   end
      if plot_components(7) ~= ' '
		   subsubplot(4, plot_count,'G Trk','deg',pos_location_matrix,plot_components(7));
	   end
      if plot_components(8) ~= ' '
		   subsubplot(5, plot_count,'G Sp','m s^{-1}',pos_location_matrix,plot_components(8));
	   end
       if the_combine ~= 0
            if plot_components(9) ~= ' '
               subsubplot(1, plot_count,'A_x','m s^{-2}',pos_data_matrix,plot_components(9));
            end
            if plot_components(10) ~= ' '
                subsubplot(2,plot_count, 'A_y','m s^{-2}',pos_data_matrix,plot_components(10));
            end
            if plot_components(11) ~= ' '
            subsubplot(3,plot_count, 'A_z','m s^{-2}',pos_data_matrix,plot_components(11));
            end
            if plot_components(12) ~= ' '
                subsubplot(4,plot_count, 'ICE','gm m^{-3}',pos_data_matrix,plot_components(12));
            end
            if plot_components(13) ~= ' '
                subsubplot(5,plot_count, 'FSSP','gm m^{-3}',pos_data_matrix,plot_components(13));
            end
            if plot_components(14) ~= ' '
                subsubplot(6,plot_count, '2D','#/l',pos_data_matrix,plot_components(14));
            end
        end
	   set(gca, 'xticklabel', date_strings);
		xlabel(datestr(time(window_start_index),0));
   end
   if (plot_components(15) ~= ' ') & (time_end > window_start_index)
	   %
	   %	Now plot aircraft location data
	   %
	   window_index = window_index + 1;
	   plot_handles(window_index) = figure;
	   axes('position',[0.1 0.1 0.7 0.7]);
	   load coast;
	   plot(pos_location_matrix(2,window_start_index:time_end),pos_location_matrix(1,window_start_index:time_end));
	   text(pos_location_matrix(2,window_start_index),pos_location_matrix(1,window_start_index),'s');
	   text(pos_location_matrix(2,time_end),pos_location_matrix(1,time_end),'e');
	%	plotm(lat,long);
	   axis equal;
	   ylabel('Latitude ');
	   xlabel('Longitude ');
	   box on;
	   V = axis;
	   if lower(plot_components(5)) == plot_components(5)
	      grid off;
	   else
	      grid on;
	   end
	   axes('position',[0.8 0.1 0.2 0.7]);
	   plot(0.001*pos_location_matrix(3,window_start_index:time_end),pos_location_matrix(1,window_start_index:time_end));
	   text(0.001*pos_location_matrix(3,window_start_index),pos_location_matrix(1,window_start_index),'s');
	   text(0.001*pos_location_matrix(3,time_end),pos_location_matrix(1,time_end),'e');
	   axis tight;
	   box on;
	   V2 = axis;
	   xlabel('Altitude (km)');
	   axis([V2(1) V2(2) V(3) V(4)]);
	   set(gca,'yticklabel',[]);
	   if lower(plot_components(5)) == plot_components(5)
	      grid off;
	   else
	      grid on;
	   end
	   axes('position',[0.1 0.8 0.7 0.2]);
	   plot(pos_location_matrix(2,window_start_index:time_end),0.001*pos_location_matrix(3,window_start_index:time_end));
	   text(pos_location_matrix(2,window_start_index),0.001*pos_location_matrix(3,window_start_index),'s');
	   text(pos_location_matrix(2,time_end),0.001*pos_location_matrix(3,time_end),'e');
	   axis tight;
	   V3 = axis;
	   box on;
	   ylabel('Altitude (km)');
	   axis([V(1) V(2) V3(3) V3(4)]);
	   set(gca,'xticklabel',[]);
	   text(V(2),V3(3)+(V3(4)-V3(3))*0.1667, datestr(time(time_end),13));
	   text(V(2),V3(3)+(V3(4)-V3(3))*0.333, datestr(time(time_end),1));
	   text(V(2),V3(4)-(V3(4)-V3(3))*0.1667, datestr(time(window_start_index),1));
	   text(V(2),V3(4)-(V3(4)-V3(3))*0.333, datestr(time(window_start_index),13));
	   if lower(plot_components(5)) == plot_components(5)
	      grid off;
	   else
	      grid on;
	   end
   end
   %
   %	Now do the POS Data plots
   %
   if (plot_count_4 > 0) & (time_end > window_start_index) & (the_combine == 0)
      plot_number = 1;
      the_title = 'Aircraft POS Data';
	   window_index = window_index + 1;
      plot_handles(window_index) = figure;
      orient(plot_handles(window_index), orientation);
      if plot_components(9) ~= ' '
		   subsubplot(1, plot_count_4,'A_x','m s^{-2}',pos_data_matrix,plot_components(9));
   	end
   	if plot_components(10) ~= ' '
		   subsubplot(2,plot_count_4, 'A_y','m s^{-2}',pos_data_matrix,plot_components(10));
   	end
   	if plot_components(11) ~= ' '
		   subsubplot(3,plot_count_4, 'A_z','m s^{-2}',pos_data_matrix,plot_components(11));
   	end
   	if plot_components(12) ~= ' '
		   subsubplot(4,plot_count_4, 'ICE','gm m^{-3}',pos_data_matrix,plot_components(12));
   	end
   	if plot_components(13) ~= ' '
		   subsubplot(5,plot_count_4, 'FSSP','gm m^{-3}',pos_data_matrix,plot_components(13));
   	end
   	if plot_components(14) ~= ' '
		   subsubplot(6,plot_count_4, '2D','#/l',pos_data_matrix,plot_components(14));
   	end
	   set(gca, 'xticklabel', date_strings);
      xlabel(datestr(time(window_start_index),0));
   end
   %
   %	Prepare for next group
   %
   window_start_index = time_end + 1;
   window_start_time = window_end_time;
end
return

function subsubplot(the_component, total_components,text_label,y_label,data_matrix,component)
global g_time g_pos_orientation_matrix g_pos_location_matrix g_pos_data_matrix window_start_index time_end plot_count plot_count_2 plot_number plot_number_2 window_start_time window_end_time g_plot_components date_strings dateform the_title
%
subplot(total_components,1,plot_number),plot(g_time(window_start_index:time_end),data_matrix(the_component,window_start_index:time_end));
if plot_number == 1
	title(the_title);
end
axis tight;
YY = axis;
YY(1) = window_start_time;
YY(2) = window_end_time;
axis(YY);
%datetick('x',dateform);
dateChoice = 'yqmwdHMS';
ax = 'x';
[ticks,dateform] = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
%ticks = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
% Set axis tick labels
labels = datestr(ticks,dateform);
set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
        [ax,'lim'],[min(ticks) max(ticks)])
date_strings = get(gca,'xticklabel');
axis(YY);
set(gca,'xticklabel',[]);
ylabel(y_label);
text(1,0.5,text_label,'Units','normalized');
plot_number = plot_number + 1;
if lower(component) == component
	grid off;
else
	grid on;
end
return

