function plot_vector_fields(field_vector,time,location_matrix,v_skip,window_width,start_string,delta_seconds)
%
%  plot_vector_fields(field_vector, time, location_matrix, v_skip, window_width, start_string, total_time)
%
%  This routine will plot lightning vectors on the xyz plots found in
%  routines such as plot_Altus_data
%
%  Inputs:
%     field_vector = (4*,N) matrix of earth oriented field values (in V/m), * at least Ew, En,Eu, Eq
%     time = (N) array of time values (in Matlab time) for the E an location data
%     location_matrix = (3,N) matrix of location data (lat, lon, alt)
%     v_skip = how often to put in vectors (i.e.,  skip = 1, do all points, skip = 10, do one in 10 points)
%     window_width = time width of individual plot windows in minutes
%     start_string = start time of first plot
%     total_time = total time of all windows
%

%
%  Set values not entered by user
%
global AIRCRAFT WHICH_AIRCRAFT
%
%  Now see if they are defined
%
if isempty(AIRCRAFT) == 1
   warning('Need to load aircraft_flags for this to work');
   WHICH_AIRCRAFT = 0;
end
if isempty(WHICH_AIRCRAFT) == 1
   warning('Need to define you aircraft (in aircraft_flags) for this to work');
   WHICH_AIRCRAFT = 0;
end
global g_time g_data_matrix window_start_index time_end plot_count plot_number plot_count_2 plot_number_2 window_start_time window_end_time g_plot_components date_strings dateform
g_time = time;
g_plot_components = [1 2 3 4 7 8 9];
plot_components = [1 2 3 4 7 8 9];
max_size = length(time);
plot_count = 7;
plot_names = ['En '; 'Ew ';'Eu ';'Eq ';'Mag';'???';'Lat';'Lon';'Alt'];
plot_units = ['V/m ';'V/m ';'V/m ';'V/m ';'V/m ';'????';'Degs';'Degs';'km  '];
if ~exist('start_string','var')
   first_time = time(1)
   start_string = datestr(time(1));
else
   if ischar(start_string) == 0
      if first_time < 1
         first_time = 1;
      end
      first_time = time(start_string);
   else
      first_time = datenum(start_string);
   end
end
if ~exist('v_skip','var')
   v_skip = 0;
end
if ~exist('delta_seconds','var')
   last_time = time(length(time))
else
   delta_seconds = delta_seconds*60;
   if delta_seconds == 0
      last_time = time(length(time));
   else
      if ischar(start_string) == 0
         last_time = time(delta_seconds+start_string);
      else
         last_time = first_time + delta_seconds*1.1574e-5;
      end
   end
end
if ~exist('window_width','var')
   window_width = 60*60;
else
   window_width = window_width*60;
   if window_width == 0
      window_width = 60*60;
   else
      if ischar(start_string) == 0
         window_width = (time(window_width) - time(1))*86400;
      end
   end
end
if ~exist('orientation','var')
   orientation = 'tall';
end
latitude = location_matrix(1,:);
longitude = location_matrix(2,:);
altitude = location_matrix(3,:);
%
%  First "fix" any Lat/Lon/Alt errors
%
if all(altitude) == 0
   for i=1:length(altitude)
      if altitude(i) == 0
         altitude(i) = NaN;
      end
   end
end
if all(latitude) == 0
   for i=1:length(latitude)
      if latitude(i) == 0
         latitude(i) = NaN;
      end
   end
end
if all(longitude) == 0
   for i=1:length(longitude)
      if longitude(i) == 0
         longitude(i) = NaN;
      end
   end
end
g_data_matrix = [field_vector; latitude; longitude; altitude];
%
%   Determine where to start & end the plots
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_size
      error('Fell off end of A/C data before hitting first time');
   end
end
first_pos_index = i
i=first_pos_index;
while time(i) < last_time
   i = i + 1;
   if i > max_size
      i = max_size;
      break;
   end
end
last_pos_index = i
window_start_time = first_time;
window_start_index = first_pos_index;
window_index = 0;
window_count = 1;
while window_start_time < last_time
   %
   %   Plot aircraft data vs. time in window
   %
   time_end = window_start_index
   window_end_time = window_start_time + (window_width*1.157407e-5);
   %
   %   Make sure we don't plot any small windows
   %
   if last_time - window_end_time < 0.1*window_width*1.157407e-5
      window_end_time = last_time;
   end
   while time(time_end) <= window_end_time
      time_end = time_end + 1;
      if time_end >= max_size
         time_end = max_size;
         break;
      end
   end
   time_end = time_end - 1;
   if time_end > window_start_index
      %
      %  Plot the data
      %
      total_plots_done = 0;
      for plot_counter=1:window_count
         window_index = window_index + 1;
         plot_handles(window_index) = figure;
         orient(plot_handles(window_index), orientation);
         plot_number = 1;
         window_start_index
         time_end
         if WHICH_AIRCRAFT ~= 0
%            the_title = AIRCRAFT(WHICH_AIRCRAFT).name;
            the_title = strcat(inputname(1),',',AIRCRAFT(WHICH_AIRCRAFT).name);
         else
            the_title = strcat('Unknown Aircraft,', inputname(1));
         end
         xlabel(sprintf('start_index;%d, end_index:%d',window_start_index,time_end));
         plot_count;
         for plot_index=1:plot_count
            the_plot_index = plot_components(plot_index + total_plots_done);
            subsubplot(plot_index,plot_count,the_plot_index,plot_names(the_plot_index,:),plot_units(the_plot_index,:),g_data_matrix, the_title);
            if plot_index == 1
               xlabel(sprintf('start index;%d, end index:%d',window_start_index,time_end));
            end
         end
         set(gca, 'xticklabel', date_strings);
         time_ticks = get(gca, 'xtick');
         xlabel(datestr(time(window_start_index),0));
         total_plots_done = total_plots_done + plot_count;
      end
      %
      %   Now plot aircraft location data
      %
      window_index = window_index + 1;
      plot_handles(window_index) = figure;
      axes('position',[0.1 0.1 0.7 0.7]);
      %
      %  Load the world coastline map
      %
      load machcoast llat llong;
      %
      %  Put start/end of plot on window
      %
      plot(longitude(window_start_index:time_end),latitude(window_start_index:time_end));
      text(longitude(window_start_index),latitude(window_start_index),'s','HorizontalAlignment','Center');
      text(longitude(time_end),latitude(time_end),'e','HorizontalAlignment','Center');
      hold;
      %
      %  Put time ticks or field vectors on window
      %
      if v_skip ~= 0
         v_values = window_start_index:v_skip:time_end;
         quiver(longitude(v_values),latitude(v_values), -0.001*field_vector(2,v_values)/6,0.001*field_vector(1,v_values)/6,0);
      end
      for tick_index=2:length(time_ticks)-1
         [alpha,beta] = min(abs(g_time(window_start_index:time_end) - time_ticks(tick_index)));
         text(longitude(window_start_index+beta-1),latitude(window_start_index+beta-1),datestr(time_ticks(tick_index),15),'HorizontalAlignment','Center','FontSize',6);
      end
      %
      %  Make the window a bit wider than the data
      %
      V = axis;
      delta_lon = 0.1*(V(2)-V(1));
      if delta_lon < 0.025
         delta_lon = 0.025;
      end
      delta_lat = 0.1*(V(4)-V(3));
      if delta_lat < 0.025
         delta_lat = 0.025;
      end
      V(1) = V(1) - delta_lon;
      V(2) = V(2) + delta_lon;
      V(3) = V(3) - delta_lat;
      V(4) = V(4) + delta_lat;
      if V(1) > V(2)
         Vx = V(1);
         V(1) = V(2);
         V(2) = Vx;
      end
      if V(3) > V(4)
         Vx = V(3);
         V(3) = V(4);
         V(4) = Vx;
      end
      %
      %  Plot the world
      %
      plot(llong,llat,'g');
      %
      %  Now we need to undistort the lat/lon plot
      %  so that 1 km north or south = 1 km east or west
      %
      globe_ratio = cos(pi*(V(3)+V(4))/360);
      current_ratio = (V(4)-V(3))/(V(2)-V(1));
      if current_ratio > globe_ratio
         %
         %  Increase the Lon dimension to undistort the plot
         %
         new_delta_lon = (V(2)-V(1))*current_ratio/globe_ratio;
         delta_lon = (new_delta_lon - V(2) + V(1))*0.5;
         V(1) = V(1) - delta_lon;
         V(2) = V(2) + delta_lon;
      else
         %
         %  Increase the Lat dimension to undistort the plot
         %
         new_delta_lat = (V(4)-V(3))*globe_ratio/current_ratio;
         delta_lat = (new_delta_lat - V(4) + V(3))*0.5;
         V(3) = V(3) - delta_lat;
         V(4) = V(4) + delta_lat;
      end         
      axis(V);
      ylabel('Latitude ');
      xlabel('Longitude ');
      box on;
      V = axis;
      grid on;
      axes('position',[0.8 0.1 0.2 0.7]);
      %
      %  Plot kilometers
      %
      plot(0.001*altitude(window_start_index:time_end),latitude(window_start_index:time_end));
      text(0.001*altitude(window_start_index),latitude(window_start_index),'s','HorizontalAlignment','Center');
      text(0.001*altitude(time_end),latitude(time_end),'e','HorizontalAlignment','Center');
      hold;
      %
      %  Put time ticks or vectors on window
      %
      if v_skip ~= 0
         v_values = window_start_index:v_skip:time_end;
         quiver(0.001*altitude(v_values),latitude(v_values), 0.001*field_vector(3,v_values),0.001*field_vector(1,v_values)/6,0);
      end
      for tick_index=2:length(time_ticks)-1
         [alpha,beta] = min(abs(g_time(window_start_index:time_end) - time_ticks(tick_index)));
         text(0.001*altitude(window_start_index+beta-1),latitude(window_start_index+beta-1),'+','HorizontalAlignment','Center');
      end
      axis tight;
      box on;
      V2 = axis;
      V2(1) = V2(1) - 0.1*(V2(2)-V2(1));
      V2(2) = V2(2) + 0.1*(V2(2)-V2(1));
       xlabel('Altitude (km)');
        axis([V2(1) V2(2) V(3) V(4)]);
      set(gca,'yticklabel',[]);
      grid on;
      axes('position',[0.1 0.8 0.7 0.2]);
      plot(longitude(window_start_index:time_end),0.001*altitude(window_start_index:time_end));
      text(longitude(window_start_index),0.001*altitude(window_start_index),'s','HorizontalAlignment','Center');
      text(longitude(time_end),0.001*altitude(time_end),'e','HorizontalAlignment','Center');
      hold;
      %
      %  Put time ticks or vectors on window
      %
      if v_skip ~= 0
         v_values = window_start_index:v_skip:time_end;
         quiver(longitude(v_values),0.001*altitude(v_values), -0.001*field_vector(2,v_values)/6,0.001*field_vector(3,v_values),0);
      end
      for tick_index=2:length(time_ticks)-1
         [alpha,beta] = min(abs(g_time(window_start_index:time_end) - time_ticks(tick_index)));
         text(longitude(window_start_index+beta-1),0.001*altitude(window_start_index+beta-1),'+','HorizontalAlignment','Center');
      end
      axis tight;
      V3 = axis;
      V3(3) = V3(3) - 0.1*(V3(4)-V3(3));
      V3(4) = V3(4) + 0.1*(V3(4)-V3(3));
      box on;
      ylabel('Altitude (km)');
      axis([V(1) V(2) V3(3) V3(4)]);
      set(gca,'xticklabel',[]);
      text(V(2),V3(3)+(V3(4)-V3(3))*0.1667, datestr(time(time_end),13));
      text(V(2),V3(3)+(V3(4)-V3(3))*0.333, datestr(time(time_end),1));
      text(V(2),V3(4)-(V3(4)-V3(3))*0.1667, datestr(time(window_start_index),1));
      text(V(2),V3(4)-(V3(4)-V3(3))*0.333, datestr(time(window_start_index),13));
      grid on;
      %
      %  Now we need to make sure the figure is square on the page (for
      %  printing)
      %
      set(gcf,'PaperPosition',[0.2500    1.5000    8.0000    8.0000]);
   end
   %
   %   Prepare for next group
   %
   window_start_index = time_end + 1;
   window_start_time = window_end_time;
end

function subsubplot(the_index, total_components,the_component,text_label,y_label,data_matrix,the_title)
global g_time g_data_matrix window_start_index time_end plot_count plot_number plot_count_2 plot_number_2 window_start_time window_end_time g_plot_components date_strings dateform
%
if the_component ==9
   subplot(total_components,1,the_index),plot(g_time(window_start_index:time_end),0.001*data_matrix(the_component,window_start_index:time_end));
else
   subplot(total_components,1,the_index),plot(g_time(window_start_index:time_end),data_matrix(the_component,window_start_index:time_end));
end
if the_index == 1
   title(the_title,'Interpreter','none');
end
axis tight;
YY = axis;
YY(1) = window_start_time;
YY(2) = window_end_time;
axis(YY);
%datetick('x',dateform);
dateChoice = 'yqmwdHMS';
ax = 'x';
[ticks,dateform] = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
%ticks = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
% Set axis tick labels
labels = datestr(ticks,dateform);
set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
        [ax,'lim'],[min(ticks) max(ticks)])
date_strings = get(gca,'xticklabel');
axis(YY);
set(gca,'xticklabel',[]);
ylabel(y_label);
text(1.01,0.95,text_label,'Units','normalized','FontSize',8,'Rotation',-90);
plot_number = plot_number + 1;
grid on;
return

