function [F, radar_values, vicinity_values, total_values, total_counts, index_values] = print_radar_at_aircraft(x_dim, y_dim, Standoff, Aircraft_Lat, Aircraft_Lon, Aircraft_Data, Time, Radar_File_Names, Radar_Directory, ats);
%
%  [F, radar_values, vicinity_values, total_values, total_counts, index_values] = print_radar_at_aircraft
%     (x_dim, y_dim, Standoff, Aircraft_Lat, Aircraft_Lon, Aircraft_Data, Time, Radar_File_Names, Radar_Directory, time_shift);
%
%  This routine determines the radar values at and near the aircraft over time
%
%  Input:
%     x_dim, y_dim = the grid locations of the data
%     Standoff = the range in km from a/c location to find the max radar value
%     Aircraft_Lat, aircraft_lon = aircraft lat & lon locations
%     Aircraft_Data = data to be plotted along with the radar data
%     Time = matlab time for aircraft data
%     Radar_File_Names = 'dir' structure of the radar files
%     Radar_Directory = location for the radar files
%     time_shift = shift radar times by this amount (minutes)
%

%
%  Set constants
%
latlon_origin = [ 28.2557 -80.6055];
standoff = Standoff;
V = [50 100 150 200 300 400 500 600];
figure_count = 1;
do_print = 1;
%
%  The aircraft time shift needs to be in
%  'Matlab' time (days)
%
aircraft_time_shift = ats*60/86400;
%
%  First, determine the first common time
%
radar_index = 1;
radar_length = length(Radar_File_Names);
aircraft_index = 1;
aircraft_length = length(Time);
a_time = Time(1) + aircraft_time_shift;
r_time = decode_radar_time(Radar_File_Names(radar_index).name);
datestr(r_time)
if a_time < r_time
   while(a_time < r_time)
      aircraft_index = aircraft_index + 1;
      if aircraft_index > aircraft_length
         error('Ran out of aircraft data before we hit the radar data start time');
      end
      a_time = Time(aircraft_index) + aircraft_time_shift;
   end
else
   while(r_time < a_time)
      radar_index = radar_index + 1;
      if radar_index > radar_length
         error('Ran out of radar data before we hit the aircraft data start time');
      end
      r_time = decode_radar_time(Radar_File_Names(radar_index).name);
   end
end
%
%  Now we have them on the same time basis, grab the first common data
%
radar_values = [];
vicinity_values = [];
total_values = [];
total_counts = [];
data_values = [];
time_values = [];
index_values = [];
the_datas = [];
t_x_diff = [];
t_y_diff = [];
movie_index = 1;
%
%  Now that we have the first set, go for the rest of the data
%
while (aircraft_index < aircraft_length) & (radar_index < radar_length)
   a_time = Time(aircraft_index) + aircraft_time_shift;
%   datestr(a_time);
   r_time = decode_radar_time(Radar_File_Names(radar_index).name);
   datestr(r_time)
   file_name = strcat(Radar_Directory, Radar_File_Names(radar_index).name)
   [radar_volume, vir0c] = load_radar_volume(file_name);
   end_aircraft_index = aircraft_index;
   end_radar_index = radar_index + 1;
   if end_radar_index > radar_length
      r_end_time = r_time + 3/(60*24);
      warning('Ran out of radar data as we hit the aircraft data start time');
   else
      r_end_time = decode_radar_time(Radar_File_Names(end_radar_index).name);
   end
   a_time = Time(end_aircraft_index) + aircraft_time_shift;
   while a_time <= r_end_time
      end_aircraft_index = end_aircraft_index + 1;
      if end_aircraft_index > aircraft_length
         warning('Ran out of aircraft data before we hit the radar data end time');
         end_aircraft_index = end_aircraft_index - 1;
         break;
      end
      a_time = Time(end_aircraft_index) + aircraft_time_shift;
   end
   the_time = Time(aircraft_index:end_aircraft_index);
   the_data = Aircraft_Data(aircraft_index:end_aircraft_index);
   the_indexes = aircraft_index:end_aircraft_index;
   aircraft_lat = Aircraft_Lat(aircraft_index:end_aircraft_index);
   aircraft_lon = Aircraft_Lon(aircraft_index:end_aircraft_index);
   [radar_value, max_radar_value, total_radar_value, total_radar_count] = get_radar_value(vir0c, latlon_origin, x_dim, y_dim, aircraft_lat, aircraft_lon, standoff);
   radar_values = [radar_values radar_value];
   vicinity_values = [vicinity_values max_radar_value];
   index_values = [index_values the_indexes];
   total_values = [total_values total_radar_value];
   total_counts = [total_counts total_radar_count];
   the_datas = [the_datas the_data];
   time_values = [time_values the_time];
   %
   %  This is a test section (printing the data)
   %
   if do_print == 1
      h1 = figure;
      subplot(10,1,6);
      plot(time_values,total_values);
      a = axis;
      t_start = time_values(end) - 25/(60*24);
      t_end = time_values(end) + 5/(60*24);
      a(1) = t_start;
      a(2) = t_end;
      axis(a),datetick('keeplimits');
      hold;
      plot(the_time,total_radar_value,'r'),ylabel('tot rdr v');
      set(gca,'XTickLabel',[]);
      subplot(10,1,7);
      plot(time_values, total_counts),ylabel('tot rdr #');
      a = axis;
      a(1) = t_start;
      a(2) = t_end;
      axis(a),datetick('keeplimits');
      hold;
      plot(the_time,total_radar_count,'r');
      set(gca,'XTickLabel',[]);
      subplot(10,1,8);
      plot(time_values, radar_values),ylabel('rdr v');
      a = axis;
      a(1) = t_start;
      a(2) = t_end;
      axis(a),datetick('keeplimits');
      hold;
      plot(the_time,radar_value,'r');
      set(gca,'XTickLabel',[]);
      subplot(10,1,9);
      plot(time_values, vicinity_values),ylabel('max rdr v');
      a = axis;
      a(1) = t_start;
      a(2) = t_end;
      axis(a),datetick('keeplimits');
      hold;
      plot(the_time,max_radar_value,'r');
      set(gca,'XTickLabel',[]);
      subplot(10,1,10);
      semilogy(time_values, the_datas),ylabel('E');
      a = axis;
      a(1) = t_start;
      a(2) = t_end;
      axis(a),datetick('keeplimits');
      hold;
      plot(the_time,the_data,'r');
%      h2 = figure;
      subplot(2,1,1);
      [C,H] = contour(x_dim,y_dim,vir0c,V);
      clabel(C,H);
      title(Radar_File_Names(radar_index).name,'interpreter','none');
      group_total = length(aircraft_lat);
      for plot_index=1:group_total
         [x_diff(plot_index),y_diff(plot_index), r_diff(plot_index)] = GPS_PosnDiff(latlon_origin(1),latlon_origin(2),aircraft_lat(plot_index),aircraft_lon(plot_index));
      end
      hold;
      plot(x_diff(1:group_total),y_diff(1:group_total),'r');
      total_length = length(t_x_diff);
      start_total = total_length - 3*group_total;
      if start_total > 0
         plot(t_x_diff(start_total:end),t_y_diff(start_total:end),'k');
      else
         plot(t_x_diff,t_y_diff,'k');
      end
%      first_name = sprintf('data%02d.png', figure_count);
%      second_name = sprintf('radar%02d.png', figure_count);
%      saveas(h1,first_name);
%      saveas(h2,second_name);
      figure_count = figure_count + 1;
      set(gcf, 'Position', [50 50 650 900]);
      F(movie_index) = getframe(gcf);
      movie_index = movie_index + 1;
      delete(h1);
%      delete(h2);
      t_x_diff = [t_x_diff x_diff(1:group_total)];
      t_y_diff = [t_y_diff y_diff(1:group_total)];
   end
   %
   %  Now back to regular code
   %
   radar_index = end_radar_index;
   aircraft_index = end_aircraft_index + 1;
   clear the_time aircraft_lat aircraft_lon;
end
movie(F);
return;

function [matlab_time] = decode_radar_time(file_string)
%
%  This one decodes the time from the radar file name
%

time_parts = sscanf(file_string,'%d_%d_%d-%2d%2d%2d');
matlab_time = datenum(2000+time_parts(1),time_parts(2),time_parts(3),time_parts(4),time_parts(5),time_parts(6));
return;
