%
%   This program processes data from the ER2 field mills.
%   What that means will undoubtedly change as it ages.
%
%
%   M.G. Bateman,  USRA,  17 Aug 1998.
%

%%% Global variables
global CurrentFile;
global MillCnt;
global StartTime;
global EndTime;
global PCtime;
global IRIGtime;
global Mill;
global MillIdx;
global MillSpeed;
global MillSpeedIdx;
global FF;
global CP;
global CPIdx;
global header;
global MillSN;
global HDR_version;
global thresh;
global plot_insens;
global NavLeftover;
global Navidx;
global Navtime;
global Alt;
global Pitch;
global Roll;
global Hdg;


%%%%% Mill cal factors
SensCal   = [24.567 24.448 24.562 24.750 24.682 24.612 24.593 24.564 24.714];
InsensCal = [448.599 0 445.836 446.271 449.274 448.011 409.496 446.864 448.609];


%%%%%  constants
NavLeftover = [];
cal_plot = 0;  % set to mill (position) number
plot_individual_mills = 1;
plot_CP = 0;
plot_speeds = 0;
plot_fields = 1;
plot_quick = 1;
plot_nav = 0;
remove_cal = 0;
quit_when_done = 0;
do_prints = 0;
FF = [2 2 2 2 1.5 1.5 1.5 1.5];
FF=[2 2 2.333 2.333 1.667 1.4 1.667 1.4];
%FF=[2 2 2.333 2.333 1.2 1.4 1.2 1.4];
MPFS = 2;
MNFS = -2;

%%%%%%%%%%%
subdir = 'C:/NASA/CAMEX-4/';
%subdir = '/tmp/work/';
header = 'Hurricane Georges Flight: 25 Sept 1998';
remove_cal = 1;

num_to_process = 1;
StartTime = [98 268 12 30 0 0];
MPFS =  2;
MNFS = -2;

%%%%%%%  Initialization
PCtime = StartTime;
build_file_name(subdir);
CurrentFile
fid = fopen(CurrentFile, 'r')
MillIdx = 1;
MillSpeedIdx = 1;
CPIdx = 1;
Navidx = 1;


% Never process more than 3 half-hour files, so init for 100 mins of data
% 50 samples * 60 secs * 100 mins = 300000
if num_to_process > 3
   disp(sprintf('Insufficient memory allocated to process %d files!', num_to_process))
   quit
end
disp('Allocating arrays...')
Mill = NaN * ones(8, 300000);
MillSpeed = NaN * ones(8, 6000);
CP = NaN * ones(3, 60000);
Alt = NaN * ones(2, 6000);
Pitch = NaN * ones(1, 6000);
Roll = NaN * ones(1, 6000);
Hdg = NaN * ones(1, 6000);


if fid == -1
   disp(sprintf('Error opening file %s', CurrentFile))
else
   file_count = 1;
   disp(sprintf('Opening file #%d: %s\n', file_count, CurrentFile))
end

buf = fread(fid,32);  % read the first block header

if length(buf) == 0
   done = 1;
else
   done = 0;
   decode_time(buf);
end


%%% main loop
while(done == 0)
   decode_time(buf);

   if PCtime(5) == 0     % every minute
      pc = sprintf('DOS: %02d%03d %02d%02d:%02d.%03d', PCtime);
      irig = sprintf('IRIG: %02d%03d %02d%02d:%02d.%03d %03d %01d-%X', IRIGtime);
      disp(sprintf('%s  %s', pc, irig))

      if rem(PCtime(4), 5) == 0     % every 5 minutes
         disp(sprintf('  Mill IDs:  QU=%d  QD=%d  RF=%d  LF=%d  RU=%d  RA=%d  LU=%d  LA=%d', MillSN));
      end
   end

   get_mill_data(fid);

   % do_kevin_dump;

   get_CP_data(fid);

   get_Nav_data(fid);


%%%%%%%%%%%
   buf = fread(fid,32);  % read another block header

   if length(buf) < 32  % EOF

      fclose(fid);
      file_count = file_count + 1;

      if file_count <= num_to_process
         build_file_name(subdir);
         fid = fopen(CurrentFile, 'r','l');
      else
         fid = -1;
      end

      if fid == -1
         done = 1;
      else
         disp(sprintf('\nOpening file #%d: %s\n', file_count, CurrentFile))
         buf = fread(fid,32);  % read first block header of new file
      end
   end

end

if fid ~= -1
   fclose(fid);
end

EndTime = PCtime;   %%% save last time


if remove_cal == 1
   disp('Removing cal pulses')
   rm_cal
end

if cal_plot ~= 0
   cal_plots(cal_plot)
   unix(sprintf('mv cal-xx.eps %s', fname))
else
   do_plots
   %other_plots
end


if quit_when_done == 1
   quit
end

