function [radar_values, vicinity_values, time_values] = radar_at_aircraft(Standoff, Aircraft_Lat, Aircraft_Lon, Time, Radar_File_Names, Radar_Directory);
%
%  [radar_values, vicinity_values, time_values] = 
%     radar_at_aircraft(Standoff, Aircraft_Lat, Aircraft_Lon, Time, Radar_File_Names, Radar_Directory);
%
%  This routine determines the radar values at and near the aircraft over time
%

%
%  Set constants
%
latlon_origin = [ 28.2557 -80.6055];
standoff = Standoff;
x_dim = -100:1:125;
y_dim = -150:1:75;
V = [50 100 150 200 300 400 500 600];
figure_count = 1;
%
%  First, determine the first common time
%
radar_index = 1;
radar_length = length(Radar_File_Names);
aircraft_index = 1;
aircraft_length = length(Time);
a_time = Time(1);
r_time = decode_radar_time(Radar_File_Names(radar_index).name);
datestr(r_time)
if a_time < r_time
   while(a_time < r_time)
      aircraft_index = aircraft_index + 1;
      if aircraft_index > aircraft_length
         error('Ran out of aircraft data before we hit the radar data start time');
      end
      a_time = Time(aircraft_index);
   end
else
   while(r_time < a_time)
      radar_index = radar_index + 1;
      if radar_index > radar_length
         error('Ran out of radar data before we hit the aircraft data start time');
      end
      r_time = decode_radar_time(Radar_File_Names(radar_index).name);
   end
end
%
%  Now we have them on the same time basis, grab the first common data
%
radar_values = [];
vicinity_values = [];
time_values = [];
t_x_diff = [];
t_y_diff = [];
%
%  Now that we have the first set, go for the rest of the data
%
while (aircraft_index < aircraft_length) & (radar_index < radar_length)
   a_time = Time(aircraft_index);
   datestr(a_time)
   r_time = decode_radar_time(Radar_File_Names(radar_index).name);
   datestr(r_time)
   file_name = strcat(Radar_Directory, Radar_File_Names(radar_index).name);
   [radar_volume, vir0c] = load_radar_volume(file_name);
   end_aircraft_index = aircraft_index;
   end_radar_index = radar_index + 1;
   if end_radar_index > radar_length
      r_end_time = r_time + 3/(60*24);
      warning('Ran out of radar data as we hit the aircraft data start time');
   else
      r_end_time = decode_radar_time(Radar_File_Names(end_radar_index).name);
   end
   while Time(end_aircraft_index) <= r_end_time
      end_aircraft_index = end_aircraft_index + 1;
      if end_aircraft_index > aircraft_length
         warning('Ran out of aircraft data before we hit the radar data end time');
         end_aircraft_index = end_aircraft_index - 1;
         break;
      end
   end
   the_time = Time(aircraft_index:end_aircraft_index);
   aircraft_lat = Aircraft_Lat(aircraft_index:end_aircraft_index);
   aircraft_lon = Aircraft_Lon(aircraft_index:end_aircraft_index);
   [radar_value, max_radar_value] = get_radar_value(vir0c, latlon_origin, x_dim, y_dim, aircraft_lat, aircraft_lon, standoff);
   %
   %  This is a test section (printing the data)
   %
   h1 = figure,plot(the_time,radar_value),datetick;
   h2 = figure;
   [C,H] = contour(x_dim,y_dim,vir0c,V);
   clabel(C,H);
   title(Radar_File_Names(radar_index).name,'interpreter','none');
   group_total = length(aircraft_lat);
   for plot_index=1:group_total
      [x_diff(plot_index),y_diff(plot_index), r_diff(plot_index)] = GPS_PosnDiff(latlon_origin(1),latlon_origin(2),aircraft_lat(plot_index),aircraft_lon(plot_index));
   end
   hold
   plot(t_x_diff,t_y_diff,'r')
   plot(x_diff(1:group_total),y_diff(1:group_total),'k');
   first_name = sprintf('data%02d.png', figure_count);
   second_name = sprintf('radar%02d.png', figure_count);
   saveas(h1,first_name);
   saveas(h2,second_name);
   figure_count = figure_count + 1;
   delete(h1);
   delete(h2);
   t_x_diff = [t_x_diff x_diff(1:group_total)];
   t_y_diff = [t_y_diff y_diff(1:group_total)];
   %
   %  Now back to regular code
   %
   radar_values = [radar_values radar_value];
   vicinity_values = [vicinity_values max_radar_value];
   time_values = [time_values the_time];
   radar_index = end_radar_index;
   aircraft_index = end_aircraft_index + 1;
   clear the_time, aircraft_lat, aircraft_lon;
end
return;

function [matlab_time] = decode_radar_time(file_string)
%
%  This one decodes the time from the radar file name
%

time_parts = sscanf(file_string,'%d_%d_%d-%2d%2d%2d');
matlab_time = datenum(2000+time_parts(1),time_parts(2),time_parts(3),time_parts(4),time_parts(5),time_parts(6));
return;
