function [continouse_data_block, test_count] = read_cont_block(fid)
%  [continouse_data_block] = read_cont_block(fid)
%
% read continuous data from SBIR data system
%
%  Inputs:
%     fid = open file ID
%
%  Output:
%       continouse_data_block = the block of data and header stuff
%       .data = [64x2048] array of the data in the file
%       .begin_header = [16] character array of the beginning header "_CONT_BLK_START_"
%       .start_time = 
%     header = array of stats about data
%           scan_ram = # of channels (should be 64)
%           gain_1 = [8] array of stage 1 gains, one for each input A/D channel (8) 
%           gain_2 = [64] array of stage 2 gains, one for each channel (64)
%           filter = [8] array of filter frequencies (8)
%

% Sample Rate:		100 Hz

%
%  Read Sync Characters
%
[tester,test_count] = fread(fid,16,'char=>char');
if test_count ~= 16
    continouse_data_block.begin_header(1) = ' ';
    return;
else
    continouse_data_block.begin_header(1,:) = tester;
end
%
%   Read header time
%
continouse_data_block.trig_time(1,:) = fread(fid,24,'char=>char');
%
%   Now read KIN_PARAMS_TYPE data
%
continouse_data_block.params.scan_ram = fread(fid,1,'uint32');
continouse_data_block.params.gain_1 = fread(fid,8,'uint32');
continouse_data_block.params.filter = fread(fid,8,'uint32');
continouse_data_block.params.gain_2 = fread(fid,[8,8],'uint32');
continouse_data_block.end_header(1,:) = fread(fid,4,'char=>char');
%if ~strcmp(continouse_data_block.end_header,'END')
%   continouse_data_block.end_header
%   warning('Header problem');
%end
%
%  Read Data, noting that there may be missing data at the end
%
continouse_data_block.data = fread(fid,[64,2048],'uint16');
count = length(continouse_data_block.data);
if count ~= 2048
   2048-count
   warning('We are missing data');
   %
   %  Fill in NaN's
   %
   for i=2048:-1:count+1
       for j=1:64
           continouse_data_block.data(j,i) = NaN;
       end
   end
end
%
%   Scale data
%
z_lev=32768;
continouse_data_block.data = (continouse_data_block.data-z_lev)./3200;
%
%   Now take out gain
%
for i=1:8
    for j=1:8
        k = (j-1)*8 + i;
        continouse_data_block.data(k,:) = continouse_data_block.data(k,:)/(continouse_data_block.params.gain_1(i)*continouse_data_block.params.gain_2(j,i));
%        continouse_data_block.data(k,i) = 0;
    end
end
