function [efm_block, nav_block] = read_dc8_block(fid);
%        [efm_block,nav_block] = read_dc8_block(fid, efm_block, nav_block);
%
% Reads one dc8 fm and nav block from the file fid and
% writes it to the structures efm_block and nav_block.
%
   
%
% Start the reading process (we will skip a lot of junk in the block)
% (We will assume the structure has already been set up)
%   The first stuff up is the nav_block data
the_year = 2001;
%
%   C Identifier (24)
%
   [nav_block.day, count] = fread(fid, 1, 'int16');
   if count ~= 1
      efm_block.version = 0;
      return;
   end
   %
   %  For now, we hard wire the year as it is not read out of the ICATS system
   %
   nav_block.year = the_year;
   [hr_min, count] = fread(fid, 1, 'int16');
   nav_block.hour = fix(hr_min/100);
   nav_block.min = mod(hr_min,100);
   [nav_block.sec,count] = fread(fid, 1, 'int32');
   nav_block.sec = nav_block.sec*0.001;
   [deg, count] = fread(fid, 1, 'int16');
   [min, count] = fread(fid, 1, 'int16');
   if deg < 0
      nav_block.latitude = deg - (min*0.1)*0.0166667;
   else
      nav_block.latitude = deg + (min*0.1)*0.0166667;
   end
   [deg, count] = fread(fid, 1, 'int16');
   [min, count] = fread(fid, 1, 'int16');
   if deg < 0
      nav_block.longitude = deg - (min*0.1)*0.0166667;
   else
      nav_block.longitude = deg + (min*0.1)*0.0166667;
   end
   [nav_block.pitch, counts] = fread(fid, 1, 'int16');
   nav_block.pitch = nav_block.pitch*0.1;
   [nav_block.roll, counts] = fread(fid, 1, 'int32');
   nav_block.roll = nav_block.roll*0.1;
   [nav_block.wind_speed, count] = fread(fid, 1, 'int16');
   %
   %    Doing D Identifier section (28)
   %
   [nav_block.wind_dir, count] = fread(fid, 1, 'int16');
   [nav_block.true_air_speed, count] = fread(fid, 1, 'int16');
   [nav_block.gnd_speed, count] = fread(fid, 1, 'int16');
   [nav_block.true_head,count] = fread(fid, 1, 'int16');
   nav_block.true_head = nav_block.true_head*0.1;
   [nav_block.drift_angle, count] = fread(fid, 1, 'int32');
   nav_block.drift_angle = nav_block.drift_angle*0.1;
   [nav_block.press_alt, count] = fread(fid, 1, 'int32');
   [nav_block.radar_alt, count] = fread(fid, 1, 'int32');
   [nav_block.dew_frost_1011, count] = fread(fid, 1, 'int32');
   [nav_block.dew_frost_300, count] = fread(fid, 1, 'int32');
   %
   %    Doing E Identifier section (24)
   %
   [nav_block.stat_air_temp, count] = fread(fid, 1, 'int16');
   nav_block.stat_air_temp = nav_block.stat_air_temp*.1;
   [nav_block.tot_air_temp, count] = fread(fid, 1, 'int16');
   nav_block.tot_air_temp = nav_block.tot_air_temp*.1;
   [nav_block.IR_surf_temp, count] = fread(fid, 1, 'int16');
   nav_block.IR_surf_temp = nav_block.IR_surf_temp*.1;
   [nav_block.stat_Tair, count] = fread(fid, 1, 'int16');
   nav_block.stat_Tair = nav_block.stat_Tair*.1;
   [nav_block.ind_air_speed, count] = fread(fid, 1, 'int16');
   [nav_block.vert_speed, count] = fread(fid, 1, 'int32');
   [nav_block.dist_togo, count] = fread(fid, 1, 'int32');
   nav_block.dist_togo = nav_block.dist_togo*0.1;
   [nav_block.time_togo, count] = fread(fid, 1, 'int32');
   nav_block.time_togo = nav_block.time_togo*0.1;
   [nav_block.align_stat, count] = fread(fid, 1, 'int16');
   %
   %	These within F identifier (26)
   %
   [nav_block.cabin_alt, count] = fread(fid, 1, 'int32');
   [nav_block.press, count] = fread(fid, 1, 'int32');
   nav_block.press = nav_block.press*0.1;
   [nav_block.mach, count] = fread(fid, 1, 'int16');
   nav_block.mach = nav_block.mach*0.001;
   [nav_block.cross_track_dist, count] = fread(fid, 1, 'int32');
   nav_block.cross_track_dist = nav_block.cross_track_dist*0.1;
   [nav_block.desired_track, count] = fread(fid, 1, 'int32');
   nav_block.desired_track = nav_block.desired_track*0.1;
   [nav_block.track_ang_err, count] = fread(fid, 1, 'int32');
   nav_block.track_ang_err = nav_block.track_ang_err*0.1;
   [nav_block.track_ang, count] = fread(fid, 1, 'int16');
   nav_block.track_ang = nav_block.track_ang*0.1;
   [nav_block.spec_humid, count] = fread(fid, 1, 'int16');
   nav_block.spec_humid = nav_block.spec_humid*0.001;
   %
   %    These within G identifier (20)
   %
   [nav_block.par_press_h20, count] = fread(fid, 1, 'int16');
   nav_block.par_press_h20 = nav_block.par_press_h20*0.1;
   [nav_block.RH_ice, count] = fread(fid, 1, 'int16');
   nav_block.RH_ice = nav_block.RH_ice*0.1;
   [nav_block.RH_wat, count] = fread(fid, 1, 'int16');
   nav_block.RH_wat = nav_block.RH_wat*0.1;
   [nav_block.sat_wat_vap_press, count] = fread(fid, 1, 'int16');
   nav_block.sat_wat_vap_press = nav_block.sat_wat_vap_press*0.01;
   [nav_block.sat_wat_vap_press_ice, count] = fread(fid, 1, 'int16');
   nav_block.sat_wat_vap_press_ice = nav_block.sat_wat_vap_press_ice*0.01;
   [nav_block.sun_elev_gnd_refracted, count] = fread(fid, 1, 'int16');
   nav_block.sun_elev_gnd_refracted = nav_block.sun_elev_gnd_refracted*0.1;
   [nav_block.sun_elev_air_refracted, count] = fread(fid, 1, 'int16');
   nav_block.sun_elev_air_refracted = nav_block.sun_elev_air_refracted*0.1;
   [nav_block.sun_azimuth_gnd_refracted, count] = fread(fid, 1, 'int16');
   nav_block.sun_azimuth_gnd_refracted = nav_block.sun_azimuth_gnd_refracted*0.1;
   [nav_block.sun_azimuth_air_refracted, count] = fread(fid, 1, 'int32');
   nav_block.sun_azimuth_air_refracted = nav_block.sun_azimuth_air_refracted*0.1;
   %
   % These within H identifier (16)
   %
   [nav_block.egi_true_hdg, count] = fread(fid, 1, 'int16');
   nav_block.egi_true_hdg = nav_block.egi_true_hdg*0.1;
   [nav_block.egi_mag_hdg, count] = fread(fid, 1, 'int16');
   nav_block.egi_mag_hdg = nav_block.egi_mag_hdg*0.1;
   [nav_block.egi_x_velocity, count] = fread(fid, 1, 'int16');
   [nav_block.egi_y_velocity, count] = fread(fid, 1, 'int16');
   [nav_block.egi_z_velocity, count] = fread(fid, 1, 'int16');
   [nav_block.egi_x_accel, count] = fread(fid, 1, 'int16');
   [nav_block.egi_y_accel, count] = fread(fid, 1, 'int16');
   [nav_block.egi_z_accel, count] = fread(fid, 1, 'int16');
   %
   %	These within I identifier (18)
   %
   [nav_block.adc_tat, count] = fread(fid, 1, 'int16');
   nav_block.adc_tat = nav_block.adc_tat*0.1;
   [nav_block.rose_tat, count] = fread(fid, 1, 'int16');
   nav_block.rose_tat = nav_block.rose_tat*0.1;
   [nav_block.potential_temp, count] = fread(fid, 1, 'int16');
   nav_block.potential_temp = nav_block.potential_temp*0.1;
   [nav_block.gps_alt_msl, count] = fread(fid, 1, 'int32');
   [nav_block.camex_dfpoint, count] = fread(fid, 1, 'int16');
   nav_block.camex_dfpoint = nav_block.camex_dfpoint*0.1;
   [nav_block.sun_elev_earth, count] = fread(fid, 1, 'int16');
   nav_block.sun_elev_earth = nav_block.sun_elev_earth*0.1;
   [nav_block.sun_elev_aircraft, count] = fread(fid, 1, 'int16');
   nav_block.sun_elev_aircraft = nav_block.sun_elev_aircraft*0.1;
   [nav_block.sun_azi_earth, count] = fread(fid, 1, 'int16');
   nav_block.sun_azi_earth = nav_block.sun_azi_earth*0.1;
   %
   % Now read the first block of junk
   %
   junk1 = fread(fid, 14, 'int8');
   %
   % Read GPS time
   %
   [efm_block.GPSTime.tm_yday, count] = fread(fid, 1, 'int16');
   [efm_block.GPSTime.tm_hour, count] = fread(fid, 1, 'int8');
   [efm_block.GPSTime.tm_min, count] = fread(fid, 1, 'int8');
   [efm_block.GPSTime.tm_sec, count] = fread(fid, 1, 'int8');
   %
   %    One byte of junk
   %
   junk2 = fread(fid, 1, 'int8');
   [efm_block.subseconds, count] = fread(fid, 1, 'int32');
   %
   % Read PC time
   %
   [efm_block.version, count] = fread(fid, 1, 'int16');
   [efm_block.pcUTC.tm_yday, count] = fread(fid, 1, 'int16');
   [efm_block.pcUTC.tm_year, count] = fread(fid, 1, 'int16');
   [efm_block.pcUTC.tm_wday, count] = fread(fid, 1, 'int8');
   [efm_block.pcUTC.tm_hour, count] = fread(fid, 1, 'int8');
   [efm_block.pcUTC.tm_min, count] = fread(fid, 1, 'int8');
   [efm_block.pcUTC.tm_sec, count] = fread(fid, 1, 'int8');
   [efm_block.pcUTC.tm_hsecond, count] = fread(fid, 1, 'int8');
   %
   %  Populate rest of strucutre
   %
   date_vec = datevec(yearday(efm_block.pcUTC.tm_year,efm_block.pcUTC.tm_yday));
   efm_block.pcUTC.tm_mon = date_vec(2)-1;
   efm_block.pcUTC.tm_mday = date_vec(3);
   %
   %  Populate rest of strucutre
   %
   date_vec = datevec(yearday(efm_block.pcUTC.tm_year,efm_block.GPSTime.tm_yday));
   efm_block.GPSTime.tm_year = date_vec(1)-1900;
   efm_block.GPSTime.tm_mon = date_vec(2)-1;
   efm_block.GPSTime.tm_mday = date_vec(3);
   efm_block.GPSTime.tm_yday;
   efm_block.GPSTime.tm_hour;
   efm_block.GPSTime.tm_min;
   efm_block.GPSTime;
   efm_block.pcUTC.tm_year = efm_block.pcUTC.tm_year - 1900;
   %
   % Read back time ?
   %
   [efm_block.back.tm_sec, count] = fread(fid, 1, 'int8');
   [efm_block.back.tm_min, count] = fread(fid, 1, 'int8');
   [efm_block.back.tm_hour, count] = fread(fid, 1, 'int8');
   [efm_block.back.tm_yday, count] = fread(fid, 1, 'int8');
   [efm_block.back.tm_mon, count] = fread(fid, 1, 'int8');
   [efm_block.back.tm_year, count] = fread(fid, 1, 'int8');
   [efm_block.back.tm_wday, count] = fread(fid, 1, 'int8');
   %
   % Convert the time to a number
   %
   efm_block.timeGPS = datenum(efm_block.GPSTime.tm_year+1900, efm_block.GPSTime.tm_mon+1, efm_block.GPSTime.tm_mday,  efm_block.GPSTime.tm_hour, efm_block.GPSTime.tm_min, efm_block.GPSTime.tm_sec);
   efm_block.timePC = datenum(efm_block.pcUTC.tm_year+1900, efm_block.pcUTC.tm_mon+1, efm_block.pcUTC.tm_mday,  efm_block.pcUTC.tm_hour, efm_block.pcUTC.tm_min, efm_block.pcUTC.tm_sec);
   %
   % Now get to the real stuff, the FM data
   %
   for i=1:6
      [efm_block.efmrecord(i).sync(1), count] = fread(fid, 1, 'int8');
      [efm_block.efmrecord(i).sync(2), count] = fread(fid, 1, 'int8');
      [efm_block.efmrecord(i).header, count] = fread(fid, 10, 'uchar');
      [efm_block.efmrecord(i).one, count] = fread(fid, 25, 'bit12',4);
      [efm_block.efmrecord(i).two, count] = fread(fid, 25, 'bit12',4);
      [efm_block.efmrecord(i).three, count] = fread(fid, 25, 'bit12',4);
      [efm_block.efmrecord(i).four, count] = fread(fid, 25, 'bit12',4);
%      for j=1:25
%         if efm_block.efmrecord(i).one(j) > 2048
%            efm_block.efmrecord(i).one(j) = efm_block.efmrecord(i).one(j) - 4096;
%         end
%         if efm_block.efmrecord(i).two(j) > 2048
%            efm_block.efmrecord(i).two(j) = efm_block.efmrecord(i).two(j) - 4096;
%         end
%         if efm_block.efmrecord(i).three(j) > 2048
%            efm_block.efmrecord(i).three(j) = efm_block.efmrecord(i).three(j) - 4096;
%         end
%         if efm_block.efmrecord(i).four(j) > 2048
%            efm_block.efmrecord(i).four(j) = efm_block.efmrecord(i).four(j) - 4096;
%         end
%      end
      [efm_block.efmrecord(i).crc, count] = fread(fid, 1, 'int16');
   end
   %
   %    Now read cal block
   %
   [efm_block.cal_buf, count] = fread(fid, 300, 'int16');
   %
   % That should be all!
   %
   return;
