function [gbfm_status_block, gbfm_data] = read_gbfm_block(fid, gbfm_status_block,gbfm_data);
%        [ gbfm_status_block, gbfm_data ] = read_gbfm_block(fid, gbfm_status_block, gbfm_data);
%
%	Reads one gbfm block (one second of data) from the file fid and
%	writes it to the structure gbfm_block.
%
%	gbfm_status_block structure:
%		.sync[4]
%		.UTC
%        .year
%        .month
%        .day
%        .hour
%        .min
%        .sec
%        .hsec
%        .msec
%		.nmills
%		.spare[3]
%		.mill[64]
%			.address
%			.mode
%			.stat[7]
%			.rain
%			.CRC
%
%  gbfm_data[50,64] = 50 data points x 64 mills
%


mill_count = 64;
%
%	Start the reading process
%	(We will assume the structure has already been set up)
%
[gbfm_status_block.sync, count] = fread(fid, 4, 'uint8');
%
%	Check if okay
%
if count ~= 4
   gbfm_status_block.sync(1) = -1;
   return;
end
for i=1:4
   if gbfm_status_block.sync(i) ~= 137
      gbfm_status_block.sync(i)
      warning('Error reading GBFM Block');
      gbfm_status_block.sync(1) = -1;
      return;
   end
end
%
%	Now read the time block
%
[gbfm_status_block.UTC.year, count] = fread(fid, 1, '*uint8');
[gbfm_status_block.UTC.month, count] = fread(fid, 1, '*uint8');
[gbfm_status_block.UTC.day, count] = fread(fid, 1, '*uint8');
[gbfm_status_block.UTC.hour, count] = fread(fid, 1, '*uint8');
[gbfm_status_block.UTC.min, count] = fread(fid, 1, '*uint8');
[gbfm_status_block.UTC.sec, count] = fread(fid, 1, 'uint8');
[gbfm_status_block.UTC.hsec, count] = fread(fid, 1, 'uint8');
[gbfm_status_block.UTC.msec, count] = fread(fid, 1, 'uint8');
%
%	Read # of mills & spare bytes
%
[gbfm_status_block.nmills, count] = fread(fid, 1, '*uint8');
[gbfm_status_block.spare, count] = fread(fid, 3, '*uint8');
%
%	Now read the 64 blocks of FM data
%
for i=1:mill_count
   [gbfm_status_block.mill(i).address, count] = fread(fid, 1, '*uint8');
   [gbfm_status_block.mill(i).mode, count] = fread(fid, 1, '*uint8');
   [gbfm_status_block.mill(i).status, count] = fread(fid, 7, '*uint8');
   [gbfm_status_block.mill(i).rain, count] = fread(fid, 1, '*uint8');
   [gbfm_data(:,i), count] = fread(fid, 50, 'int16');
   [gbfm_status_block.mill(i).crc, count] = fread(fid, 1, '*uint16');
end
%
%	Add the microseconds to the whole seconds time
%
gbfm_status_block.UTC.sec = gbfm_status_block.UTC.sec + gbfm_status_block.UTC.hsec*0.01 + gbfm_status_block.UTC.msec*0.001;
%
%	That should be all!
%
return;
