function [POS_block, POS_time] = read_pos_block(fid, base_time, POS_block, type);
%        [ POS_block, POS_time ] = read_pos_block(fid, base_time, POS_block, type);
%
%	Reads one POS block from the file fid and
%	writes it to the structure POS_block.
%
%	POS_time = time in Matlab units, using the base_time (also in
%			Matlab units) as the "seconds from midnight" base.
%	POS structure:
%		lat = latitude of aircraft
%		long = longitude of aircraft
%		speed = speed of aircraft in m/s (ground speed or airspeed?)
%		track = ground heading of aircraft
%		roll = roll angle of aircraft
%		pitch = pitch of aircraft
%		head = heading of aircraft (magnetic or true?)
%		alt = altitude of aircraft (meters)
%		dX = X acceleration (m/s**2)
%		dY = Y acceleration (m/s**2)
%		dZ = Z acceleration (m/s**2)
%		valid = POS time of validity (?)
%		GPS = POS GPS time
%		ice = ice detector LWC (gm/m**3)
%		LWC = FSSP LWC (gm/m**3)
%		two_d = 2D concentrations (p/liter)
%	type = anything if large struct wanted (leave out if want small struct)
%
%	This routine assumes any preliminary header lines have been removed
%

%
%	Read the data
%
the_string = fgetl(fid);
if length(the_string) ~= 0
   the_matrix = sscanf(the_string, ' %f');
else
   POS_block.speed = -1;
   return
end
if max(size(the_matrix)) ~= 17
   max(size(the_matrix))
   warning('Incorrect # of items read');
   POS_block.speed = -1;
   return
end
%
%	Now convert to the structure
%
POS_time = base_time + the_matrix(1)*1.1574e-5;
POS_block.lat = the_matrix(2);
POS_block.long = the_matrix(3);
POS_block.speed = the_matrix(4);
POS_block.track = the_matrix(5);
POS_block.roll = the_matrix(6);
POS_block.pitch = the_matrix(7);
POS_block.head = the_matrix(8);
POS_block.alt = the_matrix(9);
if ~exist('type')
	POS_block.dX = the_matrix(10);
	POS_block.dY = the_matrix(11);
	POS_block.dZ = the_matrix(12);
	POS_block.valid = the_matrix(13);
	POS_block.GPS = the_matrix(14);
	POS_block.ice = the_matrix(15);
	POS_block.LWC = the_matrix(16);
   POS_block.two_d = the_matrix(17);
end
