function [time_data_block,count] = read_time_block(fid)
%  [time_data_block, count] = read_time_block(fid)
%
% read time data from ACES data system
%
%  Inputs:
%     fid = open file ID
%
%  Output:
%       time_data_block = the block of data and header stuff
%       .Year8_Min = BCD digits of SYNCCLOCK time YDDDHHMM
%       .Sec40_Usec = BCD digits of SYNCCLOCK time SSMMMUUU
%       .SYNCstatus = 8 bit SYNCCLOCK status word
%       .System_Time = System time structure
%           .seconds = system time seconds
%           .nanoseconds = system time nanoseconds
%       .GPSstatus[60] = GPS status/time as a string
%       .CMOS = time of computer CMOS as a tm structure
%           .tm_sec = seconds digits of CMOS time
%           .tm_min = minutes digits of CMOS time
%           .tm_hour = hour
%           .tm_mday = day of month
%           .tm_mon = month
%	        .tm_year = year - 1900
%   	    .tm_wday = weekday
%   	    .tm_yday = day of year
%	        .tm_isdst = daylight savings time
%     count = 60 if everything is okay (we read all data)
%

[time_data_block.Year8_Min, count] = fread(fid,1,'uint32=>uint32');
if count ~= 1
   return;
end
time_data_block.Sec40_Usec = fread(fid,1,'uint32=>uint32');
time_data_block.SYNCstatus = fread(fid,1,'uint8=>uint8');
junk = fread(fid,3,'uint8=>uint8');
time_data_block.System_Time.seconds = fread(fid,1,'uint32');
time_data_block.System_Time.nanoseconds = fread(fid,1,'uint32');
[time_data_block.GPSstatus(1,:),count] = fread(fid,60,'char=>char');
time_data_block.GPSposition(1,:) = fread(fid,60,'char=>char');
time_data_block.CMOS.tm_sec = fread(fid, 1, 'int32');
time_data_block.CMOS.tm_min = fread(fid, 1, 'int32');
time_data_block.CMOS.tm_hour = fread(fid, 1, 'int32');
time_data_block.CMOS.tm_mday = fread(fid, 1, 'int32');
time_data_block.CMOS.tm_mon = fread(fid, 1, 'int32');
time_data_block.CMOS.tm_year = fread(fid, 1, 'int32');
time_data_block.CMOS.tm_wday = fread(fid, 1, 'int32');
time_data_block.CMOS.tm_yday = fread(fid, 1, 'int32');
time_data_block.CMOS.tm_isdst = fread(fid, 1, 'int32');
