function [Np,resampled_earth_E_matrix,resampled_aircraft_E_matrix,resampled_time,resampled_gain_matrix,resampled_mill_E_matrix,resampled_best_mill_E_matrix,resampled_orientation_matrix,resampled_location_matrix,resampled_pos_matrix] = resample_all_data(time,mill_E_matrix,conversion_matrix,orientation_matrix,location_matrix,pos_matrix,gain_matrix,input_sample_rate,output_sample_rate);
%   function [Np, resampled_earth_E_matrix, resampled_aircraft_E_matrix, resampled_time, resampled_gain_matrix, 
%       resampled_mill_E_matrix, resampled_best_mill_E_matrix, resampled_orientation_matrix, resampled_location_matrix, 
%       resampled_pos_matrix] = resample_all_data(time, mill_E_matrix, conversion_matrix, orientation_matrix, location_matrix, 
%       pos_matrix, gain_matrix, input_sample_rate, output_sample_rate);
%
%	This routine resamples all of the data.
%
%	Inputs:
%     time = the N array of datenum time values
%     mill_E_matrix = the (2,6,N) matrix of mill electric field values
%		conversion_matrix = the (4,6) matrix to convert a mill set of E to an aircraft set of E
%		orientation_matrix = the (3,N) matrix of aircraft orientation (roll, pitch, heading)
%		location_matrix = the (5,N) matrix of aircraft location (lat, lon, alt, trk, gspd)
%		pos_matrix = the (6,N) matrix of aircraft pos data (X_acc, Y_acc, Z_acc, Ice_LWC, FSSP_LWC, 2D_conc)
%		gain_matrix = the (6,N) matrix of gains used in the calculations (1=sensitive, 2=insensitive)
%     input_sample_rate = input sample rate of data in pps
%     output_sample_rate = output sample rate in pps
%
%   Outputs:
%     Np = # of lines in the output file
%		resampled_earth_E_matrix = the (6,Np) matrix of the earth oriented (En, Ew, Eu, Q, Emag, Qfactor) electric fields
%		resampled_aircraft_E_matrix = the (6,Np) matrix of the aircraft oriented (Ex, Ey, Ez, Q, Emag, Qfactor) electric fields
%     resampled_time = the Np array of datenum time values
%     resampled_gain_matrix = the (6,Np) matrix of resampled gains used in the calculations (1=sensitive, 2=insensitive)
%     resampled_mill_E_matrix = the (2,6,Np) matrix of mill electric field values
%     resampled_best_mill_E_matrix = the (6,Np) matrix of mill electric field values (used in the earth & aircraft matrix)
%		resampled_orientation_matrix = the (3,Np) resampled matrix of aircraft orientation (roll, pitch, heading)
%		resampled_location_matrix = the (5,Np) resampled matrix of aircraft location (lat, lon, alt, trk, gspd)
%		resampled_pos_matrix = the (6,Np) resampled matrix of aircraft pos data (X_acc, Y_acc, Z_acc, Ice_LWC, FSSP_LWC, 2D_conc)
%

%
%   Resample the data unsing blocks
%
[resampled_mill_E_matrix, resampled_time,Np] = block_resample(time,mill_E_matrix,input_sample_rate,output_sample_rate);
[resampled_orientation_matrix, resampled_time,Np] = block_resample(time,orientation_matrix,input_sample_rate,output_sample_rate);
[resampled_location_matrix, resampled_time,Np] = block_resample(time,location_matrix,input_sample_rate,output_sample_rate);
[resampled_pos_matrix, resampled_time,Np] = block_resample(time,pos_matrix,input_sample_rate,output_sample_rate);
%
%	Call the first conversion routine
%
[resampled_aircraft_E_matrix, resampled_best_mill_E_matrix, resampled_gain_matrix] = convert_mill_2_aircraft_E(resampled_mill_E_matrix,conversion_matrix);
%
%	Now call the second conversion routine
%
resampled_earth_E_matrix = convert_aircraft_2_earth_E(resampled_aircraft_E_matrix,resampled_orientation_matrix);
%
%   That is all!
%
return;
