function [latitude, longitude, altitude] = resample_er2_nav(old_latitude, old_longitude, old_altitude, old_time, new_time)
%
%  [latitude, longitude, altitude] = resample_er2_nav(old_latitude, old_longitude, old_altitude, old_time, new_time);

%  This routine resamples the nav data using interp1 and fixes the problems with NaN's
%  and other missing data
%

%
%  First, find bad data (0's) and replace them with NaN's
%
where_bad_data_is = find(old_latitude == 0);
old_latitude(where_bad_data_is) = NaN;
where_bad_data_is = find(old_longitude == 0);
old_longitude(where_bad_data_is) = NaN;
where_bad_data_is = find(old_altitude == 0);
old_altitude(where_bad_data_is) = NaN;
where_bad_data_is = find(old_time == 0);
old_time(where_bad_data_is) = NaN;
%  Now get rid of the NaN's
%
where_the_nans_are = find(isnan(old_time));
lat1 = old_latitude;
lat1(where_the_nans_are) = [];
time1 = old_time;
time1(where_the_nans_are) = [];
lon1 = old_longitude;
lon1(where_the_nans_are) = [];
alt1 = old_altitude;
alt1(where_the_nans_are) = [];
%
%  Now get rid of the NaN's left in the latitude
%
where_the_nans_are = find(isnan(lat1));
lat1(where_the_nans_are) = [];
time1(where_the_nans_are) = [];
lon1(where_the_nans_are) = [];
alt1(where_the_nans_are) = [];
%
%  Now get rid of the NaN's left in the longitude
%
where_the_nans_are = find(isnan(lon1));
lat1(where_the_nans_are) = [];
time1(where_the_nans_are) = [];
lon1(where_the_nans_are) = [];
alt1(where_the_nans_are) = [];
%
%  Now get rid of the NaN's left in the altitude
%
where_the_nans_are = find(isnan(alt1));
lat1(where_the_nans_are) = [];
time1(where_the_nans_are) = [];
lon1(where_the_nans_are) = [];
alt1(where_the_nans_are) = [];
%
%  Now find any times in the old time that are the same
%
bad_times = find(diff(time1) == 0);
lat1(bad_times) = [];
time1(bad_times) = [];
lon1(bad_times) = [];
alt1(bad_times) = [];
%
%  Now interpolate
%
latitude = interp1(time1,lat1,new_time);
longitude = interp1(time1,lon1,new_time);
altitude = interp1(time1,alt1,new_time);
%
%  That's all folks!
%
return;
