function [resampled_pos_orientation_matrix, resampled_pos_location_matrix, resampled_pos_data_matrix] = resample_pos_data(pos_orientation_matrix, pos_location_matrix, pos_data_matrix, pos_time, efm_time);
%	function [resampled_pos_orientation_matrix, resampled_pos_location_matrix, resampled_pos_data_matrix] = 
%		resample_pos_data(pos_orientation_matrix, pos_location_matrix, pos_data_matrix, pos_time, efm_time)
%
%	This routine resamples the pos data to lock with the efm data using the Matlab
%		function interp1 and cubic interp.
%
%	Inputs:
%		pos_orientation_matrix = input aircraft orientation matrix
%		pos_location_matrix = input aircraft location matrix
%		pos_data_matrix = input aircraft pos data matrix
%		pos_time = input time base
%		efm_time = efm time base
%
%	Outputs:
%		resampled_pos_orientation_matrix = aircraft orientation matrix resampled to match efm data
%		resampled_pos_location_matrix = aircraft location matrix resampled to match efm data
%		resampled_pos_data_matrix = aircraft pos data matrix resampled to match efm data
%

%
%	Preset sizes
%
new_size = length(efm_time);
resampled_pos_orientation_matrix(3,new_size) = 0;
resampled_pos_location_matrix(5,new_size) = 0;
resampled_pos_data_matrix(6,new_size) = 0;
%
%	Now do the interp
%
for index=1:3
   resampled_pos_orientation_matrix(index,:) = interp1(pos_time, pos_orientation_matrix(index,:), efm_time);
end
for index=1:5
   resampled_pos_location_matrix(index,:) = interp1(pos_time, pos_location_matrix(index,:), efm_time);
end
for index=1:6
   resampled_pos_data_matrix(index,:) = interp1(pos_time, pos_data_matrix(index,:), efm_time);
end
