function [resampled_pos_structure] = resample_pos_data_struct(pos_structure, pos_time, efm_time);
%
%	function [resampled_pos_structure] = resample_pos_data_struct(pos_structure, pos_time, efm_time);
%
%	This routine resamples the pos data to lock with the efm data using the Matlab
%		function interp1 and cubic interp.
%
%	Inputs:
%		pos_orientation_matrix = input aircraft orientation matrix
%		pos_location_matrix = input aircraft location matrix
%		pos_data_matrix = input aircraft pos data matrix
%		pos_time = input time base
%		efm_time = efm time base
%
%	Outputs:
%		resampled_pos_orientation_matrix = aircraft orientation matrix resampled to match efm data
%		resampled_pos_location_matrix = aircraft location matrix resampled to match efm data
%		resampled_pos_data_matrix = aircraft pos data matrix resampled to match efm data
%

%
%	Preset sizes
%
new_size = length(efm_time);
resampled_pos_structure = repmat(struct('roll',0,'pitch',0,'heading',0,'lat',0,'lon',0,'alt',0,'track',0,'gs',0,'X_acc',0,'Y_acc',0,'Z_acc',0,'Ice_LWC',0,'FSSP_LWC',0,'twoD_conc',0),1,new_size);
%
%	Now do the interp
%
roll = interp1(pos_time, [pos_structure.roll], efm_time);
pitch = interp1(pos_time, [pos_structure.pitch], efm_time);
heading = interp1(pos_time, [pos_structure.heading], efm_time);
lat = interp1(pos_time, [pos_structure.lat], efm_time);
lon = interp1(pos_time, [pos_structure.lon], efm_time);
alt = interp1(pos_time, [pos_structure.alt], efm_time);
track = interp1(pos_time, [pos_structure.track], efm_time);
gs = interp1(pos_time, [pos_structure.gs], efm_time);
X_acc = interp1(pos_time, [pos_structure.X_acc], efm_time);
Y_acc = interp1(pos_time, [pos_structure.Y_acc], efm_time);
Z_acc = interp1(pos_time, [pos_structure.Z_acc], efm_time);
Ice_LWC = interp1(pos_time, [pos_structure.Ice_LWC], efm_time);
FSSP_LWC = interp1(pos_time, [pos_structure.FSSP_LWC], efm_time);
twoD_conc = interp1(pos_time, [pos_structure.twoD_conc], efm_time);
%
%  Now move it on over
%
for index=1:new_size
   resampled_pos_structure(index).roll = roll(index);
   resampled_pos_structure(index).pitch = pitch(index);
   resampled_pos_structure(index).heading = heading(index);
   resampled_pos_structure(index).lat = lat(index);
   resampled_pos_structure(index).lon = lon(index);
   resampled_pos_structure(index).alt = alt(index);
   resampled_pos_structure(index).track = track(index);
   resampled_pos_structure(index).gs = gs(index);
   resampled_pos_structure(index).X_acc = X_acc(index);
   resampled_pos_structure(index).Y_acc = Y_acc(index);
   resampled_pos_structure(index).Z_acc = Z_acc(index);
   resampled_pos_structure(index).Ice_LWC = Ice_LWC(index);
   resampled_pos_structure(index).FSSP_LWC = FSSP_LWC(index);
   resampled_pos_structure(index).twoD_conc = twoD_conc(index);
end
%
%  That's all folks!
%
