function [trig_data, trigger_list] = review_fast_data(the_file_list, base_directory);
%  [trig_data, trigger_list] = review_fast_data(the_file_list, base_directory);
%
%  This routine reads in a boatload of triggered data and plots it for review.
%  The user then clicks on the appropriate button (Electrical Only, Optical+Electric,
%  Optical Only, Optical+Corona, Electrical+Corona, Corona Only, Nothing, Quit).
%  Use it to decide which of the many triggers to look at...
%
%  Inputs:
%     the_file_list(file_count,?) = char string or structure array of input files
%     base_directory = char of base directory to find files (default: current directory)
%
%  Outputs:
%     trig_data = matrix of times and type of the triggers:
%           1 = Electrical Only
%           2 = Optical+Electric
%           3 = Optical Only
%           4 = Optical+Corona
%           5 = Electrical+Corona
%           6 = Corona Only
%           7 = Nothing/Garbage
%     trigger_list = list of non-nothing triggers (anything other than 'nothing'
%        for input to sload_fast_data)
%
%
T0 = clock;
format compact;
year = 2002;
trigger_list = [];
trigger_list_length = 0;
disp('Setting defaults');
trig_name_matrix = {'OPS  Gain 1 Sig.', 'OPS  Gain 2 Sig.', 'Slo Ant - Ch-1', 'Slo Ant - Ch-2', 'Slo Ant - Ch-3', 'AC E Field  GSFC - X', 'AC E Field  GSFC - Y','AC E Field  GSFC - Z','DOPS - Ch-1','DOPS - Ch-2','Search Coil - X Sig.','Search Coil - Y Sig.','Search Coil - Z Sig.','Accel  - X Sig','Accel  - Y Sig','Accel  - Z Sig'};
trig_unit_matrix = ['volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts'];
%plot_indexx = [1 2 5 6 9 10 13 14 17 18 21 22 25 26 29 30 3 4 7 8 11 12 15 16 19 20 23 24 27 28 31 32];
plot_indexx = [1 3 5 7 9 11 13 15 2 4 6 8 10 12 14 16];
%
%    Determine the file count and file names
%
if isstruct(the_file_list)
   disp('the_file_list is a structure');
   file_count_array = size(the_file_list);
   file_count = file_count_array(1);
   for i=1:file_count
      file_list(i,:) = the_file_list(i).name;
   end
else
   disp('the_file_list is an array');
   file_count_array = size(the_file_list);
   file_count = file_count_array(1);
   file_list = the_file_list;
end
if ~exist('trigger_list','var')
   trigger_list = 1:10000;
end
   if ~exist('base_directory','var')
      base_directory = pwd;
   end
if ischar(trigger_list) == 1
   start_string = trigger_list(1,:);
   the_size = size(trigger_list);
   number_of_triggers = 9999;
   max_trigger = 9999;
   start_time = datenum(start_string);
   if the_size(1) == 2
      end_string = trigger_list(2,:);
      end_time = datenum(end_string);
   else
      end_time = start_time + 1000000;
      end_string = ' ';
   end
   start_string
   end_string
   trigger_list = 0;
else
   start_time = 0;
   end_time = 0;
   max_trigger = max(trigger_list);
   number_of_triggers = max(size(trigger_list));
   max_trigger = max(trigger_list);
   number_of_triggers = max(size(trigger_list));
end
default_size = 65536;
M = default_size;
N = number_of_triggers;
cut_off = 0;
order = 2;
trigger_count = 0;
%
% Init the data
%
disp('Init data');
summary_count = 0;
T0 = clock;
Ntot = 0;
time_base = 'XXX';
fast_data(16,default_size) = 0;
time_array(default_size) = 0;
block_data(16,65536) = 0;
filtered_block_data(16,65536) = 0;
block_time(65536) = 0;
which_one = 0;
%
% Open file
%
N=0;
block_index = 1;
last_time = 0;
%
%  Decode the date of the data (for file name use)
%
file_data = sscanf(file_list(1,:),'ACES_TRIG_V%f_%4d-%3d');
file_year = file_data(2) - 100*floor(file_data(2)*0.01);
file_day = file_data(3);
full_file_name = sprintf('%02d%03doptical_pulse_list.txt',file_year,file_day);
disp(strcat('Reading from:',full_file_name));
%fidb = fopen(strcat(base_directory,'\',full_file_name),'r');
fidb = -1;
%
%  See if there is a data file, otherwise we can ignore the next part
%
times_done = 0;
if fidb ~= -1
   %
   %  we need to see how far we have come in the data
   %
   frewind(fidb);
   the_string = fgetl(fidb);
   while ischar(the_string)
      times_done = times_done + 1;
      the_string
      t_d = sscanf(the_string,'%f %4d-%2d-%2d %2d:%2d:%f %d');
      for index = 1:8
         trig_data(times_done,index) = t_d(index);
      end
      the_string = fgetl(fidb);
   end
   %
   %  we now have all of the previous work in a variable, clear the file
   %  and start looking for new data
   %
   fclose(fidb);
end
for i=1:file_count
   %
   % Open next file
   %
   disp('Opening next file');
   if exist('base_directory','var')
      disp(strcat(base_directory,'\',file_list(i,:)));
      fid1 = fopen(strcat(base_directory,'\',file_list(i,:)),'r');
   else
      fid1 = fopen(file_list(i,:),'r');
   end
   if fid1 == -1
      warning('Could not open file');
   end
   file_block_count = 0;
   %
   % Read first block of data
   %
   [fast_block_1, count] = read_trig_block(fid1);
   [fast_block_2, count] = read_trig_block(fid1);
   [fast_block_3, count] = read_trig_block(fid1);
   [fast_block_4, count] = read_trig_block(fid1);
   fast_block_current = fast_block_1;
   count;
   disp('Load Data');
   while count == 16
      trigger_count = trigger_count + 1;
%      trigger_count
      %
      %  Decode the string time to a matlab time
      %
      summary_data.s_time = fast_block_current.trig_time;
      summary_data.s_time
      time_val = sscanf(summary_data.s_time, '%3d:%2d:%2d:%f');
      [month, day] = DOY_2_mon_day(time_val(1), year);
      hour = time_val(2);
      minute = time_val(3);
      data_second = time_val(4);
      summary_data.m_time = datenum(year,month,day,hour,minute,data_second);
%      datestr(summary_data.m_time)
      if times_done == 0
         test_time = 0;
      else
         test_time = trig_data(times_done,1);
      end
      if summary_data.m_time > test_time
         disp('Found Trigger');
         %
         %  Set the next time in the trigger output list
         %
         times_done = times_done + 1;
         trig_data(times_done,1) = summary_data.m_time;
         trig_data(times_done,2) = year;
         trig_data(times_done,3) = month;
         trig_data(times_done,4) = day;
         trig_data(times_done,5) = hour;
         trig_data(times_done,6) = minute;
         trig_data(times_done,7) = data_second;
         %
         %  Trigger is in the list, read summary
         %
         summary_data.trig_loc = fast_block_current.params.trig_loc;
         summary_data.attenuation = fast_block_current.params.attenuation;
         summary_data.atten_state = fast_block_current.params.atten_state;
         summary_data.coupling = fast_block_current.params.coupling;
         summary_data.filter = fast_block_current.params.filter;
         summary_data.gain = fast_block_current.params.gain;
         summary_data.input_state = fast_block_current.params.input_state;
         summary_data.output_state = fast_block_current.params.output_state;
         summary_data.voltage = fast_block_current.params.voltage;
         summary_data.ch_range = fast_block_current.header.ch_range;
         summary_data.scale = fast_block_current.header.scale;
         summary_data.channel = fast_block_current.header.channel;
         summary_data.threshold = fast_block_current.header.threshold;
         summary_data.level = fast_block_current.header.level;
         summary_data.numbytes = fast_block_current.header.numbytes;
         summary_data.res_group = fast_block_current.header.res_group;
         summary_data.trig_group = fast_block_current.header.trig_group;
         %
         % Read in the data
         %
         fast_data(1:4,:) = fast_block_1.data(1:4,:);
         fast_data(5:8,:) = fast_block_2.data(1:4,:);
         fast_data(9:12,:) = fast_block_3.data(1:4,:);
         fast_data(13:16,:) = fast_block_4.data(1:4,:);
         %
         %  Set time
         %
         scale_time = summary_data.scale;
%         for sub_time_index=1:65536
%            time_array(sub_time_index) = (sub_time_index - scale_time)*5e-6;
%         end
         time_array = ((1:65536) - scale_time)*5e-6 + time_val(4);
         %
         %  Now plot the data on one page
         %
         if which_one == 0
            plot_handles = figure;
            set(plot_handles,'Position',[0 50 2000 950])
         end
         for plot_index=1:16
            subplot(8,2,plot_indexx(plot_index)),plot(time_array,fast_data(plot_index,:));
            the_axis = axis;
            if (the_axis(4)-the_axis(3)) < 0.2
               delta = (0.2 - (the_axis(4)-the_axis(3)))*0.5;
               the_axis(3) = the_axis(3) - delta;
               the_axis(4) = the_axis(4) + delta;
            end
            axis tight;
            new_axis = axis;
            axis([new_axis(1) new_axis(2) the_axis(3) the_axis(4)]);
%            grid;
            text(1.02,0.99,trig_name_matrix(plot_index),'Units','normalized','FontSize',6,'Rotation',-90);
            set(gca,'FontSize',7);
         end
         the_title = sprintf('File:%s   Trig Time:%s', strcat(base_directory,'\',file_list(i,:)),summary_data.s_time);
         if which_one == 0
            subplot(8,2,1),text(0,1.5,the_title,'Units','normalized','Interpreter','none','FontSize',12);
         else
            subplot(8,4,3),text(0,1.5,the_title,'Units','normalized','Interpreter','none','FontSize',12);
         end
         orient(plot_handles, 'landscape');
         if summary_data.trig_group == 0
            channel = 0;
         else
            channel = summary_data.channel + (summary_data.trig_group - 1)*4;
         end
         the_title = sprintf('Pre-trig:%d    Trig Chan:%d    Thres:%s    Trig Lvl:%f   Trig#:%d',summary_data.scale, channel, summary_data.threshold, summary_data.level,trigger_count);
         if which_one == 0
            subplot(8,2,15),text(0,-0.5,the_title,'Units','normalized','Interpreter','none','FontSize',12);
         else
            subplot(8,4,31),text(0,-0.5,the_title,'Units','normalized','Interpreter','none','FontSize',12);
         end
         which_one = which_one + 1;
         if which_one == 1
            R = menu('Pulse Type','Electrical Only', 'Optical+Electric','Optical Only','Optical+Corona','Electrical+Corona', 'Corona Only', 'Nothing', 'Quit');
            %
            %  If user entered in anyting but nothing or quit, add this trigger to the list
            %
            if R < 7
               trigger_list_length = trigger_list_length + 1
               trigger_list(trigger_list_length) = times_done
            end
            if R == 8
               %
               %  Done for this time, write out data so far
               %
               close(plot_handles);
%               disp(strcat('Writing Results to:',full_file_name));
%               fidb = fopen(strcat(base_directory,'\',full_file_name),'w');
               e_only = 0;
               o_p_e = 0;
               o_only = 0;
               o_p_c = 0;
               e_p_c = 0;
               c_only = 0;
               noth = 0;
               for index=1:times_done-1
                  %
                  %  write data to file
                  %
%                  fprintf(fidb,'%f %4d-%02d-%02d %02d:%02d:%f %d\n',trig_data(index,:));
                  %
                  %  Do quick stats
                  %
                  switch(trig_data(index,8))
                  case 1
                     e_only = e_only + 1;
                  case 2
                     o_p_e = o_p_e + 1;
                  case 3
                     o_only = o_only + 1;
                  case 4
                     o_p_c = o_p_c + 1;
                  case 5
                     e_p_c = e_p_c + 1;
                  case 6
                     c_only = c_only + 1;
                  case 7 
                     noth = noth + 1;
                  end
               end
               %
               %  Write out stats
               %
               the_stats = sprintf('E Only:%d, O+E:%d, O Only:%d, O+C:%d, E+C:%d, C Only:%d, Nothing:%d', e_only, o_p_e, o_only, o_p_c, e_p_c, c_only, noth);
               disp(the_stats);
%               fclose(fidb);
               trig_data(times_done,:) = [];
               return;
            else
               trig_data(times_done,8) = R;
            end
            close(plot_handles);
            which_one = 0;
         end
      end
      %
      % Get the next trigger
      %
      last_block = fast_block_current;
      file_block_count = file_block_count + 1;
      [fast_block_1,count] = read_trig_block(fid1);
      [fast_block_2, count] = read_trig_block(fid1);
      [fast_block_3, count] = read_trig_block(fid1);
      [fast_block_4, count] = read_trig_block(fid1);
      fast_block_current = fast_block_1;
      if trigger_count > max_trigger
         break;
      end
   end
   %
   % Get the next file
   %
   fclose(fid1);
end
summary_count
%
%  Fell off end of file, write out ALL trigger data
%
%disp(strcat('Writing Final Results to:',full_file_name));
%fidb = fopen(strcat(base_directory,'\',full_file_name),'w');
e_only = 0;
o_p_e = 0;
o_only = 0;
o_p_c = 0;
e_p_c = 0;
c_only = 0;
noth = 0;
for index=1:times_done
%   fprintf(fidb,'%f %4d-%02d-%02d %02d:%02d:%f %d\n',trig_data(index,:));
   %
   %  Do quick stats
   %
   switch(trig_data(index,8))
   case 1
      e_only = e_only + 1;
   case 2
      o_p_e = o_p_e + 1;
   case 3
      o_only = o_only + 1;
   case 4
      o_p_c = o_p_c + 1;
   case 5
      e_p_c = e_p_c + 1;
   case 6
      c_only = c_only + 1;
   case 7 
      noth = noth + 1;
   end
end
%
%  Write out stats
%
the_stats = sprintf('E Only:%d, O+E:%d, O Only:%d, O+C:%d, E+C:%d, C Only:%d, Nothing:%d', e_only, o_p_e, o_only, o_p_c, e_p_c, c_only, noth);
disp(the_stats);
%fclose(fidb);
%
%  Time the data processing
%
etime(clock,T0)
