function [resampled_matrix] = row_resample(the_matrix,input_sample_rate,output_sample_rate);
%   function [resampled_matrix] = row_resample(the_matrix, input_sample_rate, output_sample_rate);
%
%	This routine resamples all of the data.  It will also attempt to "fix" NaN gaps by
%   reducing the filter length near NaN gaps.
%
%	Inputs:
%     the_matrix = the (A,B,C,N) matrix of data (will sample down the LAST column)
%     input_sample_rate = input sample rate of data in pps
%     output_sample_rate = output sample rate in pps
%
%   Outputs:
%		resampled_matrix = the (A,B,C,N*output_sample_rate/input_sample_rate) matrix of the resampled data
%

%
%   first determine the array depth
%
the_dims = size(the_matrix);
dim_count = max(size(size(the_matrix)));
if dim_count > 4
    error('We cant do 5 or more dimensions');
end
%
%   Resample the data down the rows
%
switch dim_count
case 1
    %
    %   Only one dimension, did not need to use this routine (other than the NaN stuff), but we will
    %
    resampled_matrix = resample(the_matrix,output_sample_rate,input_sample_rate);
    %
    %   Attempt to fix NaN gaps
    %
    if any(isnan(resampled_matrix))
        resample_5 = resample(the_matrix,output_sample_rate,input_sample_rate,5);
        resample_0 = resample(the_matrix,output_sample_rate,input_sample_rate,0);
        new_length = length(resample_5);
        for j=1:new_length
            if isnan(resampled_matrix(j))
                resampled_matrix(j) = resample_5(j);
                if isnan(resampled_matrix(j))
                    resampled_matrix(j) = resample_0(j);
                end
            end
        end
    end
case 2
    %
    %   Do the rows
    %
    for i=1:the_dims(1)
        resampled_matrix(i,:) = resample(the_matrix(i,:),output_sample_rate,input_sample_rate);
        %
        %   Attempt to fix NaN gaps
        %
        if any(isnan(resampled_matrix(i,:)))
            resample_5 = resample(the_matrix(i,:),output_sample_rate,input_sample_rate,5);
            resample_0 = resample(the_matrix(i,:),output_sample_rate,input_sample_rate,0);
            new_length = length(resample_5);
            for j=1:new_length
                if isnan(resampled_matrix(i,j))
                    resampled_matrix(i,j) = resample_5(j);
                    if isnan(resampled_matrix(i,j))
                        resampled_matrix(i,j) = resample_0(j);
                    end
                end
            end
        end
    end
case 3
    %
    %   Do the rows
    %
    for i=1:the_dims(1)
        for j=1:the_dims(2)
            resampled_matrix(i,j,:) = resample(the_matrix(i,j,:),output_sample_rate,input_sample_rate);
            %
            %   Attempt to fix NaN gaps
            %
            if any(isnan(resampled_matrix(i,j,:)))
                resample_5 = resample(the_matrix(i,j,:),output_sample_rate,input_sample_rate,5);
                resample_0 = resample(the_matrix(i,j,:),output_sample_rate,input_sample_rate,0);
                new_length = length(resample_5);
                for k=1:new_length
                    if isnan(resampled_matrix(i,j,k))
                        resampled_matrix(i,j,k) = resample_5(k);
                        if isnan(resampled_matrix(i,j,k))
                            resampled_matrix(i,j,k) = resample_0(k);
                        end
                    end
                end
            end
        end
    end
case 4
    %
    %   Do the rows
    %
    for i=1:the_dims(1)
        for j=1:the_dims(2)
            for k=1:the_dims(3)
                resampled_matrix(i,j,k,:) = resample(the_matrix(i,j,k,:),output_sample_rate,input_sample_rate);
                %
                %   Attempt to fix NaN gaps
                %
                if any(isnan(resampled_matrix(i,j,k,:)))
                    resample_5 = resample(the_matrix(i,j,k,:),output_sample_rate,input_sample_rate,5);
                    resample_0 = resample(the_matrix(i,j,k,:),output_sample_rate,input_sample_rate,0);
                    new_length = length(resample_5);
                    for l=1:new_length
                        if isnan(resampled_matrix(i,j,k,l))
                            resampled_matrix(i,j,k,l) = resample_5(l);
                            if isnan(resampled_matrix(i,j,k,l))
                                resampled_matrix(i,j,k,l) = resample_0(l);
                            end
                        end
                    end
                end
            end
        end
    end
end
%
%   That's It!
%
return;
