function [rule_matrix,test_index] = rule_test(E_values, variable_1, variable_2,E_lo, E_mid, E_hi, var_1_limit, var_2_limit, test_element);
%
%  function rule_matrix = rule_test(E_values, variable_1, variable_2,E_lo, E_mid, E_hi, var_1_limit, var_2_limit);
%
%  This routine tests a rule
%
%  rule_matrix = 4x4 matrix:
%     (4,1) = E below E_lo, neither rule violate
%     (3,1) = E below E_lo, variable_1 rule violated 
%     (2,1) = E below E_lo, variable_2 rule violated
%     (1,1) = E below E_lo, both rules violated
%     (4,2) = E below E_mid, E above E_lo, neither rule violate
%     (3,2) = E below E_mid, E above E_lo, variable_1 rule violated 
%     (2,2) = E below E_mid, E above E_lo, variable_2 rule violated
%     (1,2) = E below E_mid, E above E_lo, both rules violated
%     (4,3) = E below E_hi, E above E_mid, neither rule violate
%     (3,3) = E below E_hi, E above E_mid, variable_1 rule violated 
%     (2,3) = E below E_hi, E above E_mid, variable_2 rule violated
%     (1,3) = E below E_hi, E above E_mid, both rules violated
%     (4,4) = E above E_hi, neither rule violate
%     (3,4) = E above E_hi, variable_1 rule violated 
%     (2,4) = E above E_hi, variable_2 rule violated
%     (1,4) = E above E_hi, both rules violated
%

%
%  Pre-set rule_matrix
%
if ~exist('test_element','var')
   test_element = [0 0];
end
test_count = 1;
test_index(1) = 0;
rule_matrix = zeros(4,4);
data_size = length(E_values);
if length(variable_1) ~= data_size
   error('Variable_1 & E are not the same size');
end
if length(variable_2) ~= data_size
   error('Variable_2 & E are not the same size');
end
for loop_count=1:data_size
   %
   %  Check for E value
   %
   if E_values(loop_count) < E_lo
      E_index = 1;
   elseif E_values(loop_count) < E_mid
      E_index = 2;
   elseif E_values(loop_count) < E_hi
      E_index = 3;
   elseif isnan(E_values(loop_count)) == 0
      E_index = 4;
   else
      continue;
   end
   %
   %  Check for rule violations
   %
   if variable_1(loop_count) > var_1_limit
      v_1 = 1;
   elseif isnan(variable_1(loop_count)) == 0
      v_1 = 0;
   else
      continue;
   end
   if variable_2(loop_count) > var_2_limit
      v_2 = 2;
   elseif isnan(variable_2(loop_count)) == 0
      v_2 = 0;
   else
      continue;
   end
   V_index = 4 - v_1 - v_2;
   %
   %  Now do the tally, mon
   %
   rule_matrix(V_index,E_index) = rule_matrix(V_index,E_index) + 1;
   if V_index == test_element(1)
      if E_index == test_element(2)
         test_index(test_count) = loop_count;
         test_count = test_count + 1;
      end
   end
end
