function [s_data, size] = sget_mill_data(fid)
%
%    This function reads (and decodes) the mill data.
%

%
%  M.G. Bateman, USRA, 17 Aug 1998
%  mod by Mach, 4/21/03
%

global Current_File;
global Mill_Count;
global Gain_Count;
global Mill;
global MillIdx;
global MillSpeed;
global MillSpeedIdx;
global MillSN;
global Milltime;
global plot_insens;
global FF;
global StartTime;
global EndTime;
global PCtime;
global IRIGtime;
global Time;
global MillStatus;

%
% Voltage levels:  5 Volts / 65536
conv     = (5/65536);
Gain_Count = 2;

%
%  Allocate temp buffer for data
%
mill_data = zeros(50);

MillSN = [];
%
%  Setup time
%
julian_time = IRIGtime(1)*1000 + IRIGtime(2);
base_string = julian(julian_time);
base_time = datenum(base_string) + (IRIGtime(3) + (IRIGtime(4) + IRIGtime(5)*1.666667e-2)*1.666667e-2)*4.16666667e-2;
time_inc = 2.314814e-7;
for mill_index = 1:Mill_Count
   %
   %  Read channel header
   %
   buf = fread(fid,10);
   s_data.header(mill_index,:) = buf;
   %
   %  Check sync
   %
   if(buf(1) ~= 'D')
      disp(sprintf('MILL DATA HDR: Sync problem!? (%c) in file %s', buf(1), Current_File));
      error('Mill sync problem');
   end
   %
   %  Check size of data (should be 214)
   %
   size = 256*buf(4) + buf(3);
   if size == 214
      millhdr = fread(fid, 12);
      s_data.millhdr(mill_index,:) = millhdr;
      id = fix(millhdr(3) / 8);
      Milltime(mill_index) = from_bcd(millhdr(6));
      s_data.id(mill_index) = id;
      MillSN = [ MillSN id ];
      %
      %  Read raw mill data & convert to volts
      %
      for gain_index=1:Gain_Count
         mill_data = fread(fid, 50, 'short');
         Mill(gain_index,mill_index,MillIdx:MillIdx+49) = conv*mill_data;
      end
      s_data.CRC(mill_index) = fread(fid, 1, 'short');
      %
      % lower 6 bits of the 8th byte
      %
      speed = rem(millhdr(8), 64);     
      s_data.speed(mill_index) = speed;
      MillSpeed(mill_index,MillSpeedIdx) = speed;
   elseif size > 0
      %
      %  skip over short packets
      %
      buf = fread(fid, size);
      MillSN = [ MillSN 0 ];
   else
      MillSN = [ MillSN 0 ];
   end
end
%
%  Do time conversion
%
the_mean = mean(Milltime);
if (the_mean > 59) || (the_mean < 0)
   the_mean
end
time_fix = the_mean - IRIGtime(5);
if time_fix > 0
   time_fix = time_fix - 60;
end
for time_index=0:49
   Time(time_index+MillIdx) = base_time + time_inc*time_index - time_fix*1.1574e-5;
   %
   %  Load calibration status
   %
   if size == 214
      for mill_index=1:Mill_Count
         MillStatus(mill_index,time_index+MillIdx) = uint8(bitand(s_data.millhdr(mill_index,4),15));
      end
   end
end
%
%  Prepare for next bunch of data
%
MillIdx = MillIdx + 50;
MillSpeedIdx = MillSpeedIdx + 1;


