function simb(plot_it)
%**********************************************************************************************
% Program repeatedly creates-reads-closes simm.dat and simo.dat simulated cal maneuver datasets
% to compute the (6x4) M matrix. Each cal dataset created is associated with a different Mtrue
% which is a baseline M plus a perturbation matrix (selected from a normal distribution). For 
% each analysis of the datasets, the following errors are assumed:
%      1. static mill offsets, 
%      2. static small error to the QCRs,
%      3. static (systematic) error to the fair weather field estimate,
%      4. nonstatic random error to each pth estimate of the fair weather field.
% Here, "static" means the error doesn't change from one aircraft maneuver to another. The 
% retrieved M (Mret) is compared to the known true M (Mtrue).
% Next, each component of a storm field and aircraft charge is pulled from a normal distribution,
% the associated storm mill outputs and mill values (m) are made, and the retrieved
% field is computed (Inv(Mret)m) and compared with the pulled storm E.
%**********************************************************************************************
% Initialize constants 
if ~exist('plot_it','var')
   plot_it = 0;
end
h=pi/180.0; 
eta=6;
mm=4;
uu=[3,0,0,2];
vv=[5,2,1,3];
fid3 = fopen('F:\NASA\ABFM\matrix testing\simb.txt','w');
%
%**********************************************************************************************
% Gish constants
c1=81.8;
c2=0.00452;
c3=38.6;
c4=0.000375;
c5=10.27;
c6=0.000121;
%
% Aircraft Speed in meters/sec (89.4 m/s is about 200mph)% head/ylat/xlon are dummy constants
speed=89.4;
head=0;
ylat=0;
xlon=0;
%**********************************************************************************************
% Define Arrays
mbase=zeros(eta,4);
dm=zeros(eta,4); 
avec=zeros(eta,1);
moff=zeros(eta,1);
lvec=zeros(mm,1);
lamstar=zeros(mm,1);
elam=zeros(mm,1);
ktrue=zeros(mm,4);
vstorm=zeros(4,1);
lstorm=zeros(mm,1);
true_mill = zeros(6,2251);
roll(2251) = 0;
pitch(2251) = 0;
alt(2251) = 0;
sumdiff = zeros(6,4);
sumdiffdiff = zeros(6,4);
%**********************************************************************************************
% Baseline M (choose Doug's best matrix for the Citation) 
%mbase(1,1)= 1.6637; mbase(1,2)= 0.3488; mbase(1,3)=-0.8892; mbase(1,4)=3.4588;
%mbase(2,1)= 3.6272; mbase(2,2)= 0.3738; mbase(2,3)= 1.7853; mbase(2,4)=3.7973;
%mbase(3,1)= 3.7833; mbase(3,2)=-2.4924; mbase(3,3)=-1.4772; mbase(3,4)=3.3949;
%mbase(4,1)= 1.7872; mbase(4,2)=-2.5072; mbase(4,3)= 2.0125; mbase(4,4)=3.8329;
%mbase(5,1)= 0.6018; mbase(5,2)= 7.3844; mbase(5,3)=-4.2242; mbase(5,4)=2.5077;
%mbase(6,1)=-1.4789; mbase(6,2)= 0.0611; mbase(6,3)= 1.1776; mbase(6,4)=1.6087; 
%**********************************************************************************************
%**********************************************************************************************
% Baseline M (choose a "good" aircraft) 
mbase(1,1)= 2.6; mbase(1,2)= 1.9; mbase(1,3)=-1.5; mbase(1,4)= 3.6;
mbase(2,1)= 2.6; mbase(2,2)= 1.5; mbase(2,3)= 1.9; mbase(2,4)= 3.6;
mbase(3,1)= 2.6; mbase(3,2)=-1.9; mbase(3,3)=-1.5; mbase(3,4)= 3.6;
mbase(4,1)= 2.6; mbase(4,2)=-1.5; mbase(4,3)= 1.9; mbase(4,4)= 3.6;
mbase(5,1)=-0.6; mbase(5,2)=-0.1; mbase(5,3)=-0.5; mbase(5,4)= 0.8;
mbase(6,1)=-1.4; mbase(6,2)= 0.1; mbase(6,3)= 0.9; mbase(6,4)= 1.7; 
%**********************************************************************************************
mbase
% Iterate
magm=0.5;
magoff=0.0;
rmoff = 0.0;
maglam=0.01;
mag1=5.0;
mag2=3.0;
magv1=5000.0;
magv2=20000.0;
nit=500;
storm_E = zeros(4,nit);
storm_Eest = zeros(4,nit);
%
seed=1439.0; nstat=0;
%
%  Set random number generator to a random value
%
randn('state',sum(100*clock));
for iter=1:nit
   %
   %     Assign the const mill offsets, the QCR errors, and the systematic psi error
   %
   for i=1:eta
      moff(i)=magoff*randn(1);
   end
   moff;
   for kk=1:mm
      elam(kk)=maglam*randn(1);
   end
   ep1=mag1*randn(1);
   ep1;
   %
   %  Create Mtrue
   %
   dm=magm*randn(eta,4);
   mbase;
   mtrue=mbase+dm;
   %
   %  Find Mtrue inverse
   %
   Mtinv = pinv(mtrue);
   %
   %  Create Simulated Cal datasets from Mtrue
   %
   z=2000;
%   fid1 = fopen('F:\nasa\abfm\matrix testing\simm.txt','w');
%   fid2 = fopen('F:\nasa\abfm\matrix testing\simo.txt','w'); 
%   fid4 = fopen('F:\nasa\abfm\matrix testing\simn.txt','w'); 
   for t=0:2250
      if (t >= 1000) & (t < 2000) 
         rsim=40*sin((t-1000)*pi/500);
      else 
         rsim=0;
      end
      if (t >= 2000) & (t < 2250)
         psim=10*sin((t-2000)*pi/125); 
      else 
         psim=0;
      end
      if (t >= 2001) & (t < 2250)
         tmid=(2*t-1)/2;
         pmid=10*sin((tmid-2000)*pi/125);
      else
         pmid=0;
      end
      z=z+speed*sin(pmid*h);
      psi=-(c1*exp(-c2*z)+c3*exp(-c4*z)+c5*exp(-c6*z)) + 2*randn(1);
      psii(t+1) = psi;
      if (t >= 2000) & (t < 2250)
         eqf=abs(25*sin((t-2000)*pi/125));
      else 
         eqf=0;
      end
      %
      %  Do Eq calibration
      %
      if (t >= 100) & (t < 200)
         eqf = 4000;
      end
      if (t >= 200) & (t < 300)
         eqf = -4000;
      end
      vsim=[psi*sin(psim*h); psi*sin(rsim*h)*cos(psim*h); psi*cos(rsim*h)*cos(psim*h); eqf];
      asim=mtrue*vsim;
%      fprintf(fid4,'%15.3f %15.3f %15.3f %15.3f %15.3f \n',t,vsim(1),vsim(2),vsim(3),vsim(4));
      time3(t+1) = t;
      Ext(t+1) = vsim(1);
      Eyt(t+1) = vsim(2) + 2*randn(1);
      Ezt(t+1) = vsim(3) + 2*randn(1);
      Eqt(t+1) = vsim(4) + 2*randn(1);
%      fprintf(fid1,'%15.3f %15.3f %15.3f %15.3f %15.3f %15.3f %15.3f \n',t,asim(1),asim(2),asim(3),asim(4),asim(5),asim(6));
      time1(t+1) = t;
      for i=1:6
         true_mill(i,t+1) = asim(i);
      end
%      fprintf(fid2,'%15.3f %15.3f %15.3f %15.3f %15.3f %15.3f %15.3f \n',t,rsim,psim,head,ylat,xlon,z);
      time2(t+1) = t;
      roll(t+1) = rsim;
      pitch(t+1) = psim;
      alt(t+1) = z;
   end
%   fclose(fid1);
%   fclose(fid2);
%   fclose(fid4);
   %
   %  Now read in the "true" mill outputs and roll/pitch data
   %
%   fid1 = fopen('F:\nasa\abfm\matrix testing\simm.txt','r');
%   fid2 = fopen('F:\nasa\abfm\matrix testing\simo.txt','r'); 
%   data1 = fscanf(fid1,' %f',[7,2251]);
%   time1 = data1(1,:);
%   true_mill = data1(2:7,:);
%   fclose(fid1);
%   data2 = fscanf(fid2,' %f',[7,2251]);
%   time2 = data2(1,:);
%   roll = data2(2,:);
%   pitch = data2(3,:);
%   alt = data2(7,:);
   %
   %  Now offset the mill data with both random and constant values
   %
   for i=1:6
      mill(i,:) = true_mill(i,:) + moff(i) + rmoff*randn(1,2251);
   end
   %
   %  Plot the mill data to see how badly we messed it up
   %
   if plot_it == 1
      for i=1:6
         subplot(6,1,i),plot(mill(i,:));
         hold;
         plot(true_mill(i,:),'r');
      end
   end
   %
   %  Plot the "true" E data
   %
 %  fid4 = fopen('F:\nasa\abfm\matrix testing\simn.txt','r');
 %  data3 = fscanf(fid4,' %f',[5,2251]);
 %  time3 = data3(1,:);
 %  Ext = data3(2,:);
 %  Eyt = data3(3,:);
 %  Ezt = data3(4,:);
 %  Eqt = data3(5,:);
   if plot_it == 1
      figure;
      subplot(4,1,1),plot(Ext);
      title('True E');
      subplot(4,1,2),plot(Eyt);
      subplot(4,1,3),plot(Ezt);
      subplot(4,1,4),plot(Eqt);
   end
   %
   %  Now we start "estimating" M.....
   %
   %  Assume a constant external E (fair weather) and do the roll/pitch stuff
   %
   Efw = -26.3*ones(1,2251);
   Eq = zeros(1,2251);
   Eq(100:199) = +5000;
   Eq(200:299) = -5000;
   Ez = Efw.*cos(roll*pi/180).*cos(pitch*pi/180);
   Ex = Efw.*sin(pitch*pi/180);
   Ey = Efw.*sin(roll*pi/180);
%test
%   Ex = Ext;
%   Ey = Eyt;
%   Ez = Ezt;
%   Eq = Eqt;
   if plot_it == 1
      figure;
      subplot(4,1,1),plot(Ex);
      title('Estimated E');
      subplot(4,1,2),plot(Ey);
      subplot(4,1,3),plot(Ez);
      subplot(4,1,4),plot(Eq);
   end
   %
   %  Build the Eest
   %
   E(1,:) = Ex;
   E(2,:) = Ey;
   E(3,:) = Ez;
   E(4,:) = Eq;
   E(5,:) = ones;
   first_M = mill/E;
   %
   %  Now use this first M estimate to recalculate E
   %
   fM = first_M(:,1:4);
   C1 = pinv(fM);
   E1 = C1*mill;
   if plot_it == 1
      figure;
      subplot(4,1,1),plot(E1(1,:));
      title('Second Estimated E');
      subplot(4,1,2),plot(E1(2,:));
      subplot(4,1,3),plot(E1(3,:));
      subplot(4,1,4),plot(E1(4,:));
   end
   %
   %  Now we have the "improved" E, redo M
   %
   E1(5,:) = ones;
   %second_M = mill(:,1000:end)/E1(:,1000:end);
   second_M = mill/E1;
   sM = second_M(:,1:4);
   diff = sM-mtrue;
   sumdiff = sumdiff + diff;
   sumdiffdiff = sumdiffdiff + diff.*diff;
   C2 = pinv(sM);
   E2 = C2*mill;
   if plot_it == 1
      figure;
      subplot(5,1,1),plot(E2(1,:));
      title('Third Estimated E');
      subplot(5,1,2),plot(E2(2,:));
      subplot(5,1,3),plot(E2(3,:));
      subplot(5,1,4),plot(E2(4,:));
      subplot(5,1,5),plot(sqrt(E2(1,:).*E2(1,:) +E2(2,:).*E2(2,:) +E2(3,:).*E2(3,:)))
      hold
      subplot(5,1,5),plot(-psii,'g')
      figure;
      subplot(4,1,1),plot(E2(1,:)-Ext);
      title('Third Estimated E - True E');
      subplot(4,1,2),plot(E2(2,:)-Eyt);
      subplot(4,1,3),plot(E2(3,:)-Ezt);
      subplot(4,1,4),plot(E2(4,:)-Eqt);
   end
   dmean(iter) = mean(abs(sqrt(E2(1,:).*E2(1,:) +E2(2,:).*E2(2,:) +E2(3,:).*E2(3,:)) - abs(psii)));
   dstd(iter) = std(abs(sqrt(E2(1,:).*E2(1,:) +E2(2,:).*E2(2,:) +E2(3,:).*E2(3,:)) - abs(psii)));
   %
   %  Now do an example "storm" field case to see how different the "est" is from the "true"
   %
   storm_E(1,iter) = magv1*randn(1);
   storm_E(2,iter) = magv1*randn(1);
   storm_E(3,iter) = magv2*randn(1);
   storm_E(4,iter) = magv2*randn(1);
   storm_mill = mtrue*storm_E(:,iter);
   storm_Eest(:,iter) = C2*storm_mill;
end
%
%  Now do stats
%
dmed = median(dmean)
dmstd = median(dstd)
the_mean = sumdiff/iter
the_std = sumdiffdiff/iter - the_mean.*the_mean
%if plot_it == 1
   figure;
   subplot(4,1,1),plot(storm_E(1,:));
   title('Storm E');
   subplot(4,1,2),plot(storm_E(2,:));
   subplot(4,1,3),plot(storm_E(3,:));
   subplot(4,1,4),plot(storm_E(4,:));
   figure;
   subplot(4,1,1),plot(storm_Eest(1,:));
   title('Estimated Storm E');
   subplot(4,1,2),plot(storm_Eest(2,:));
   subplot(4,1,3),plot(storm_Eest(3,:));
   subplot(4,1,4),plot(storm_Eest(4,:));
   figure;
   abs_est = abs(storm_Eest-storm_E);
   subplot(4,1,1),plot(abs_est(1,:));
   title('Estimated Storm E - True Storm E');
   subplot(4,1,2),plot(abs_est(2,:));
   subplot(4,1,3),plot(abs_est(3,:));
   subplot(4,1,4),plot(abs_est(4,:));
   figure;
   abs_ratio = abs_est./abs(storm_E);
   subplot(4,1,1),plot(abs_ratio(1,:));
   title('(Estimated Storm E - True Storm E)/True Storm E');
   subplot(4,1,2),plot(100*abs_ratio(2,:));
   subplot(4,1,3),plot(100*abs_ratio(3,:));
   subplot(4,1,4),plot(100*abs_ratio(4,:));
   %end
abs_ratio = abs((storm_Eest-storm_E)./abs(storm_E));
Exmean = 100*median(abs_ratio(1,:))   
Eymean = 100*median(abs_ratio(2,:))   
Ezmean = 100*median(abs_ratio(3,:))   
Eqmean = 100*median(abs_ratio(4,:))
   