function [syncclock_time, syncclock_m_time, system_time, system_m_time, gps_time, gps_m_time, cmos_time, cmos_m_time] = sload_time_data(the_file_list, base_directory);
%  [syncclock_time, syncclock_m_time, system_time, system_m_time, gps_time, gps_m_time, cmos_time, cmos_m_time] 
%     = sload_time_data(the_file_list, base_directory);
%
%  This routine loads a boatload of time data into two sets of arrays, one in Matlab
%  dateform format and one in seconds from the first file name
%
%  Inputs:
%     the_file_list(file_count,?) = char string or structure array of input files
%     directory = char of base directory to find files (default: current directory)
%  Outputs:
%     syncclock_time = time found at the syncclock (VSI-SYnCCLOCK-32) in seconds from first file name
%     syncclock_m_time = time found at the syncclock (VSI-SYnCCLOCK-32) in Matlab dateform format
%     system_time = system time  in seconds from first file name
%     system_m_time = system time in dateform format
%     gps_time = time found at the GPS unit in seconds from first file name
%     gps_m_time = time found at GPS unit in dateform
%     cmos_time = time found at the computer CMOS in seconds from first file name
%     cmos_m_time = time found at the computer CMOS in dateform
%

%
%  Set any defaults
%
T0 = clock;
format compact;
disp('Setting defaults');
base_year = 2000;
%
%    Determine the file count and file names
%
if isstruct(the_file_list)
   disp('the_file_list is a structure');
   file_count_array = size(the_file_list);
   file_count = file_count_array(1);
   for i=1:file_count
      file_list(i,:) = the_file_list(i).name;
   end
else
   disp('the_file_list is an array');
   file_count_array = size(the_file_list);
   file_count = file_count_array(1);
   file_list = the_file_list;
end
data_index = 0;
%
%  Now read the data
%
for i=1:file_count
   %
   %  Open next file
   %
   disp('Opening next file');
   if exist('base_directory','var')
      disp(strcat(base_directory,'\',file_list(i,:)));
      fid1 = fopen(strcat(base_directory,'\',file_list(i,:)),'r');
   else
      disp(file_list(i,:));
      fid1 = fopen(file_list(i,:),'r');
   end
   if fid1 == -1
      warning('Could not open file');
   end
   %
   %  Determine the base time from the file name
   %
   the_base_time = sscanf(file_list(i,:),'ACES_TIME_V2.50_%d-%dT%d-%d-%d');
   year = the_base_time(1);
   [month, day] = DOY_2_mon_day(the_base_time(2), year);
   if i == 1
      base_m_time = datenum(year,month,day,the_base_time(3),the_base_time(4),the_base_time(5));
      base_time = (base_m_time - datenum(base_year,1,1))*86400;
   end
   %
   %  Read first block
   %
   [time_data_block,count] = read_time_block(fid1);
   disp('Loading data');
   while count == 60
      data_index = data_index + 1;
      [syncclock_time(data_index), syncclock_m_time(data_index)] = BCD_convert(base_m_time, base_year, time_data_block.Year8_Min, time_data_block.Sec40_Usec);
      [system_time(data_index), system_m_time(data_index)] = timespec_convert(base_m_time, time_data_block.System_Time.seconds,time_data_block.System_Time.nanoseconds);
      [gps_time(data_index), gps_m_time(data_index)] = GPS_convert(base_m_time, time_data_block.GPSstatus);
      [cmos_time(data_index), cmos_m_time(data_index)] = tm_convert(base_m_time, time_data_block.CMOS);
      %
      %  Read next time block
      %
      [time_data_block,count] = read_time_block(fid1);
   end
end
return

