function sview_fast_data(the_file_list, base_directory, action, trigger_list);
%  sview_fast_data(the_file_list, base_directory, action, trigger_list);
%
%  This routine reads in a boatload of triggered data, decimates it, and plots it for review.
%  Use it to decide which of the many triggers to look at...
%
%  Inputs:
%     the_file_list(file_count,?) = char string or structure array of input files
%     base_directory = char of base directory to find files (default: current directory)
%     action = character on what to do, 'P' plot the triggers on the printer, 'T' list times and 
%        trigger #'s only, 'V' plot on screen/do not print
%     trigger_list = array of trigger #'s to download (default all) OR 2D string of start/stop
%        limits for triggers (the program will figure out the type of trigger list)
%        Note: if trigger_list == -1, will print ALL triggers (same if left blank)
%
%  For example (to print ALL triggers in the file 'trigger_file' in directory 'the_directory':
%
%     sview_fast_data('trigger_file','the_directory');
%
T0 = clock;
format compact;
year = 2002;
disp('Setting defaults');
trig_name_matrix = {'OPS  Gain 1 Sig.', 'OPS  Gain 2 Sig.', 'Slo Ant - Ch-1', 'Slo Ant - Ch-2', 'Slo Ant - Ch-3', 'AC E Field  GSFC - X', 'AC E Field  GSFC - Y','AC E Field  GSFC - Z','DOPS - Ch-1','DOPS - Ch-2','Search Coil - X Sig.','Search Coil - Y Sig.','Search Coil - Z Sig.','Accel  - X Sig','Accel  - Y Sig','Accel  - Z Sig'};
trig_unit_matrix = ['volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts'];
plot_indexx = [1 2 5 6 9 10 13 14 17 18 21 22 25 26 29 30 3 4 7 8 11 12 15 16 19 20 23 24 27 28 31 32];
%
%    Determine the file count and file names
%
if isstruct(the_file_list)
   disp('the_file_list is a structure');
   file_count_array = size(the_file_list);
   file_count = file_count_array(1);
   for i=1:file_count
      file_list(i,:) = the_file_list(i).name;
   end
else
   disp('the_file_list is an array');
   file_count_array = size(the_file_list);
   file_count = file_count_array(1);
   file_list = the_file_list;
end
if ~exist('action','var')
   action = 'P';
else
   if action ~= 'P'
      if action ~= 'V'
         if action ~= 'T'
            action = 'P';
         end
      end
   end
end
if ~exist('trigger_list','var')
   trigger_list = 1:1000;
end
   if ~exist('base_directory','var')
      base_directory = pwd;
   end
if ischar(trigger_list) == 1
   start_string = trigger_list(1,:);
   the_size = size(trigger_list);
   number_of_triggers = 999;
   max_trigger = 999;
   start_time = datenum(start_string);
   if the_size(1) == 2
      end_string = trigger_list(2,:);
      end_time = datenum(end_string);
   else
      end_time = start_time + 1000000;
      end_string = ' ';
   end
   start_string
   end_string
   trigger_list = 0;
else
   start_time = 0;
   end_time = 0;
   max_trigger = max(trigger_list);
   number_of_triggers = max(size(trigger_list));
   max_trigger = max(trigger_list);
   number_of_triggers = max(size(trigger_list));
end
default_size = 65536;
M = default_size;
N = number_of_triggers;
cut_off = 0;
order = 2;
trigger_count = 0;
%
% Init the data
%
disp('Init data');
summary_count = 0;
T0 = clock;
Ntot = 0;
time_base = 'XXX';
fast_data(16,default_size) = 0;
time_array(default_size) = 0;
block_data(16,65536) = 0;
filtered_block_data(16,65536) = 0;
block_time(65536) = 0;
which_one = 0;
%
% Open file
%
N=0;
block_index = 1;
last_time = 0;
for i=1:file_count
   %
   % Open next file
   %
   disp('Opening next file');
   if exist('base_directory','var')
      disp(strcat(base_directory,'\',file_list(i,:)));
      fid1 = fopen(strcat(base_directory,'\',file_list(i,:)),'r');
   else
      fid1 = fopen(file_list(i,:),'r');
   end
   if fid1 == -1
      warning('Could not open file');
   end
   file_block_count = 0;
   %
   % Read first block of data
   %
   [fast_block_1, count] = read_trig_block(fid1);
   [fast_block_2, count] = read_trig_block(fid1);
   [fast_block_3, count] = read_trig_block(fid1);
   [fast_block_4, count] = read_trig_block(fid1);
   fast_block_current = fast_block_1;
   count;
   disp('Load Data');
   while count == 16
      trigger_count = trigger_count + 1;
      %
      %  Decode the string time to a matlab time
      %
      summary_data.s_time = fast_block_current.trig_time;
      time_val = sscanf(summary_data.s_time, '%3d:%2d:%2d:%f');
      [month, day] = DOY_2_mon_day(time_val(1), year);
      hour = time_val(2);
      minute = time_val(3);
      data_second = time_val(4);
      summary_data.m_time = datenum(year,month,day,hour,minute,data_second);
      if (all(trigger_list - trigger_count) == 0) | ((summary_data.m_time >= start_time) & (summary_data.m_time < end_time))
         timer_string = sprintf('%04d-%02d-%02d %02d:%02d:%06.3f %d',year, month, day, hour, minute, data_second, trigger_count);
         disp(timer_string);
         %
         %  Trigger is in the list, read summary
         %
         summary_data.trig_loc = fast_block_current.params.trig_loc;
         summary_data.attenuation = fast_block_current.params.attenuation;
         summary_data.atten_state = fast_block_current.params.atten_state;
         summary_data.coupling = fast_block_current.params.coupling;
         summary_data.filter = fast_block_current.params.filter;
         summary_data.gain = fast_block_current.params.gain;
         summary_data.input_state = fast_block_current.params.input_state;
         summary_data.output_state = fast_block_current.params.output_state;
         summary_data.voltage = fast_block_current.params.voltage;
         summary_data.ch_range = fast_block_current.header.ch_range;
         summary_data.scale = fast_block_current.header.scale;
         summary_data.channel = fast_block_current.header.channel;
         summary_data.threshold = fast_block_current.header.threshold;
         summary_data.level = fast_block_current.header.level;
         summary_data.numbytes = fast_block_current.header.numbytes;
         summary_data.res_group = fast_block_current.header.res_group;
         summary_data.trig_group = fast_block_current.header.trig_group;
         %
         % Read in the data
         %
         fast_data(1:4,:) = fast_block_1.data(1:4,:);
         fast_data(5:8,:) = fast_block_2.data(1:4,:);
         fast_data(9:12,:) = fast_block_3.data(1:4,:);
         fast_data(13:16,:) = fast_block_4.data(1:4,:);
         %
         %  Set time
         %
         scale_time = summary_data.scale;
%         for sub_time_index=1:65536
%            time_array(sub_time_index) = (sub_time_index - scale_time)*5e-6;
%         end
         time_array = ((1:65536) - scale_time)*5e-6 + time_val(4);
         if action ~= 'T'
            %
            %  Now plot the data on one page
            %
            if which_one == 0
               plot_handles = figure;
            end
            for plot_index=1:16
               subplot(8,4,plot_indexx(plot_index+which_one*16)),plot(time_array,fast_data(plot_index,:));
               the_axis = axis;
               if (the_axis(4)-the_axis(3)) < 0.2
                  delta = (0.2 - (the_axis(4)-the_axis(3)))*0.5;
                  the_axis(3) = the_axis(3) - delta;
                  the_axis(4) = the_axis(4) + delta;
               end
               axis tight;
               new_axis = axis;
               axis([new_axis(1) new_axis(2) the_axis(3) the_axis(4)]);
               grid;
               text(1.02,0.99,trig_name_matrix(plot_index),'Units','normalized','FontSize',6,'Rotation',-90);
               set(gca,'FontSize',6);
            end
            the_title = sprintf('File:%s   Trig Time:%s', strcat(base_directory,'\',file_list(i,:)),summary_data.s_time);
            if which_one == 0
               subplot(8,4,1),text(0,1.5,the_title,'Units','normalized','Interpreter','none','FontSize',6);
            else
               subplot(8,4,3),text(0,1.5,the_title,'Units','normalized','Interpreter','none','FontSize',6);
            end
            orient(plot_handles, 'landscape');
            if summary_data.trig_group == 0
               channel = 0;
            else
               channel = summary_data.channel + (summary_data.trig_group - 1)*4;
            end
            the_title = sprintf('Pre-trig:%d    Trig Chan:%d    Thres:%s    Trig Lvl:%f   Trig#:%d',summary_data.scale, channel, summary_data.threshold, summary_data.level,trigger_count);
            if which_one == 0
               subplot(8,4,29),text(0,-0.5,the_title,'Units','normalized','Interpreter','none','FontSize',6);
            else
               subplot(8,4,31),text(0,-0.5,the_title,'Units','normalized','Interpreter','none','FontSize',6);
            end
            which_one = which_one + 1;
            if which_one == 2
               if action == 'P'
                  print(plot_handles);
               end
               close(plot_handles);
               which_one = 0;
            end
         end
      end
      %
      % Get the next trigger
      %
      last_block = fast_block_current;
      file_block_count = file_block_count + 1;
      [fast_block_1,count] = read_trig_block(fid1);
      [fast_block_2, count] = read_trig_block(fid1);
      [fast_block_3, count] = read_trig_block(fid1);
      [fast_block_4, count] = read_trig_block(fid1);
      fast_block_current = fast_block_1;
      if trigger_count > max_trigger
         break;
      end
   end
   %
   % Get the next file
   %
   fclose(fid1);
end
summary_count
%
%  Time the data processing
%
etime(clock,T0)
